# 1 "yacc.m"
struct _PRIVATE { struct _PRIVATE *isa; };
typedef struct _PRIVATE *id;
struct _SHARED {
  id isa;
  id clsSuper;
  char *clsName;
  char *clsTypes;
  short clsSizInstance;
  short clsSizDict;
  struct _SLT *clsDispTable;
  long clsStatus;
  struct modDescriptor *clsMod;
  unsigned clsVersion;
  id clsCats;
  id *clsGlbl;
};
extern id  (* _imp(id,char*))();
extern id  (* _impSuper(id,char*))();
extern struct modDescriptor  *_OBJCBIND_yacc(void);
static char **selTransTbl;
struct _SLT {char *_cmd;id (*_imp)();};
struct modDescriptor {
  char *modName;
  char *modVersion;
  long modStatus;
  char *modMinSel;
  char *modMaxSel;
  id *modClsLst;
  short modSelRef;
  char **modSelTbl;
  struct methodDescriptor *modMapTbl;
};
extern struct modDescriptor yacc_modDesc;

# 2 "yacc.m"
static char yysccsid[]="@(#)yaccpar	1.9 (Berkeley) 02/21/93";
# 1 "../../util/stdarg.h"
#include <stdarg.h>

# 1 "../../util/stdlib.h"
#include <stdlib.h>

# 1 "../../util/assert.h"
#include <assert.h>

# 1 "../../util/string.h"
#include <string.h>

# 1 "../../util/stdio.h"
#include <stdio.h>

# 1 "../../util/stdio.h"
#include <stdio.h>

# 1 "../../util/stddef.h"
#include <stddef.h>

# 53 "../../include/objcrt/objcrt.h"
typedef char*SEL;
typedef char*STR;
typedef char BOOL;
typedef FILE*IOD;
typedef id SHR;
# 62 "../../include/objcrt/objcrt.h"
typedef id(*IMP)();


typedef void(*ARGIMP)(id,SEL,void*);
# 85 "../../include/objcrt/objcrt.h"
extern BOOL msgFlag;
extern FILE*msgIOD;
extern FILE*dbgIOD;
extern BOOL allocFlag;
extern BOOL dbgFlag;
extern BOOL noCacheFlag;
extern BOOL noNilRcvr;
# 98 "../../include/objcrt/objcrt.h"
SEL selUid(STR);
STR selName(SEL);
void dbg(char*fmt,...);
void prnstack(FILE*file);
void loadobjc(void*modPtr);
void unloadobjc(void*modPtr);
# 107 "../../include/objcrt/objcrt.h"
IMP fwdimp(id,SEL,IMP);
IMP fwdimpSuper(id,SEL,IMP);
void fwdmsg(id,SEL,void*,ARGIMP);
id selptrfwd(id,SEL,id,id,id,id);


id idincref(id obj);
id idassign(id*lhs,id rhs);
id iddecref(id obj);

extern id(*_fileIn)(FILE*);
extern BOOL(*_fileOut)(FILE*,id);
extern BOOL(*_storeOn)(STR,id);
extern id(*_readFrom)(STR);
void setfilein(id(*f)(FILE*));
void setfileout(BOOL(*f)(FILE*,id));

extern id(*_showOn)(id,unsigned);

void*OC_Malloc(size_t);
void*OC_MallocAtomic(size_t);
void*OC_Calloc(size_t);
void*OC_Realloc(void*,size_t);
void*OC_Free(void*data);
# 1 "../../util/string.h"
#include <string.h>

# 32 "../../include/objpak/ocstring.h"
typedef struct objstr
{
int count;
int capacity;
char*ptr;
}*
objstr_t;
# 22 "../oclib/options.h"
void defoptions(void);

extern int o_warnings;
extern int o_gnu;
extern int o_vms;
extern int o_refcnt;
extern int o_ppi;
extern int o_watcom;
extern int o_ibmvac;
extern int o_msdos;
extern int o_enableasm;
extern int o_nolinetags;
extern int o_buffered;
extern int o_quiet;
extern int o_outputcode;
extern int o_version;
extern int o_otb;
extern int o_llkeyw;
extern int o_comments;
extern int o_duptypedefs;
extern int o_seltranslation;
extern int o_categories;
extern int o_blocks;
extern int o_fwd;
extern int o_selptr;
extern int o_cache;
extern int o_filer;
extern int o_selfassign;
extern char*o_bind;
extern char*o_browsedir;
extern int o_refbind;
extern int o_inlinecache;
extern int o_cplus;
extern int o_gencode;
extern int o_st80;
extern int o_selfassign;
extern int o_nilrcvr;
extern int o_shareddata;
extern int o_oneperfile;
extern int o_cvars;
extern int o_warnlex;
extern int o_warnfwd;
extern int o_warnsuggest;
extern int o_warnintvar;
extern int o_warnclasstype;
extern int o_warntypeconflict;
extern int o_warnundefined;
extern int o_warnlocalnst;
extern int o_warnnotfound;
extern int o_warnmissingmethods;
extern int o_postlink;
extern char*o_infile;
extern char*o_outfile;
extern char*o_srcfilename;
extern char*o_initcall;
extern char*o_tagformat;
extern char*o_mainfun;
extern char*o_pathsep;
extern int o_debuginfo;
extern int o_checkbind;
extern int o_linemax;
extern int o_structassign;
extern id o_stepbreak;
extern int o_stepnext;
# 22 "../oclib/node.h"
extern FILE*gfile;
extern int inlineno;
extern id infilename;
extern int outlineno;
extern char*outfilename;
extern int exitstatus;
extern id loadedmodules;

void gc(char c);
void gextc(void);
void gcom(char*cm);
void gvarlist(id c,char*sp,char*iz);
void gcommalist(id c);
void gs(char*str);
void gf(char*fmt,...);
void gl(int no,char*fn);
void g_otbvars(void);
void gstderr(void);
void gnormal(void);
char*browsepath(char*filename);

void warn(char*fmt,...);
void warnat(id sym,char*fmt,...);
void fatal(char*fmt,...);
void fatalat(id sym,char*fmt,...);
# 23 "../oclib/util.h"
extern FILE*yyin;
extern int yyparse();

FILE*openfile(STR name,STR modfs);
FILE*reopenfile(STR name,STR modfs,FILE*of);

extern int okblock;

id mkcppdirect(char*s);
id mkexprstmt(id expr);
id mklabeledstmt(id label,id stmt);
id mkcasestmt(id keyw,id expr,id stmt);
id mkdefaultstmt(id keyw,id stmt);
id mkifstmt(id keyw,id expr,id stmt);
id mkifelsestmt(id keyw,id expr,id stmt,id ekeyw,id estmt);
id mkswitchstmt(id keyw,id expr,id stmt);
id mkwhilestmt(id keyw,id expr,id stmt);
id mkdostmt(id keyw,id stmt,id wkeyw,id expr);
id mkforstmt(id keyw,id a,id b,id c,id stmt);
id mkgotostmt(id keyw,id label);
id mkcontinuestmt(id keyw);
id mkbreakstmt(id keyw);
id mkreturnstmt(id keyw,id expr);
id mkcastexpr(id a,id b);
id mkcondexpr(id a,id b,id c);
id mkunaryexpr(STR op,id a);
id mksizeof(id a);
id mktypeof(id kw,id a);
id mkaddressof(id a);
id mkdereference(id a);
id mkbinexpr(id a,STR op,id b);
id mkcommaexpr(id a,id b);
id mkrelexpr(id a,STR op,id b);
id mkassignexpr(id a,STR op,id b);
id mkfuncall(id funname,id args);
id mkbuiltincall(id funname,id args);
id mkfunbody(id datadefs,id compound);
void declarefun(id specs,id decl);
void declaremeth(BOOL factory,id decl);
id mkfundef(id specs,id decl,id body);
id mkmethdef(BOOL factory,id decl,id body);
id mkmesgexpr(id receiver,id args);
id mkdecl(id ident);
id mkprecdecl(id tquals,id decl);
id mkarraydecl(id lhs,id ix);
id mkfundecl(id lhs,id args);
id mkprefixdecl(id lhs,id rhs);
id mkpostfixdecl(id lhs,id rhs);
id mkpointer(id specs,id pointer);
id mkbitfielddecl(id decl,id expr);
id mkstardecl(id pointer,id decl);
id mkasmop(id string,id expr);
id mkasmstmt(id keyw,id tqual,id expr,id asmop1,id asmop2,id clobbers);
id mkcompstmt(id lb,id datadefs,id stmtlist,id rb);
id mklist(id c,id s);
id mklist2(id c,id s,id t);
id atdefsaddall(id c,id n);
id mkblockexpr(id lb,id parms,id datadefs,id stmts,id expr,id rb);
id mkclassdef(id keyw,id name,id sname,id ivars,id cvars);
id mkdatadef(id datadef,id specs,id decl,id initializer);
id mkencodeexpr(id name);
id mkenumspec(id keyw,id name,id lb,id list,id rb);
id mkenumerator(id name,id value);
id mkgnuattrib(id anyword,id exprlist);
id mkgnuattribdecl(id keyw,id list);
id mklistexpr(id lb,id x,id rb);
id mktypename(id specs,id decl);
id mkcomponentdef(id cdef,id specs,id decl);
id mkstructspec(id keyw,id name,id lb,id defs,id rb);
id mkkeywarg(id sel,id arg);
id mkkeywdecl(id sel,id cast,id arg);
id mkmethproto(id cast,id usel,id ksel,BOOL varargs);
id mkidentexpr(id name);
id mkconstexpr(id name,id schain);
id mkprecexpr(id expr);
id mkbracedgroup(id expr);
id mkarrowexpr(id array,id ix);
id mkdotexpr(id array,id ix);
id mkindexexpr(id array,id ix);
id mkpostfixexpr(id expr,id pf);
id mkparmdef(id parmdef,id specs,id decl);
id mkparmdeflist(id idents,id parmdefs,BOOL varargs);
id mkselarg(id selarg,id usel,int ncols);
id mkselectorexpr(id expr);

void procextdef(id def);
void finclassdef(void);
void datadefokblock(id datadef,id specs,id decl);

id mkfileinmeth(id classdef,id ivarnames,id ivartypes);
id mkfileoutmeth(id classdef,id ivarnames,id ivartypes);

id mkincrefsmeth(id classdef,id ivarnames,id ivartypes);
id mkdecrefsmeth(id classdef,id ivarnames,id ivartypes);
# 86 "y.tab.c"
short yylhs[]={ -1,
1,1,1,1,1,5,5,3,3,3,
3,3,3,10,10,12,12,12,12,9,
15,15,15,16,18,18,19,19,22,19,
23,23,24,24,26,26,26,26,26,26,
26,26,26,26,26,26,26,27,27,30,
30,32,32,33,33,21,21,21,21,36,
36,36,36,36,36,38,38,38,38,20,
20,20,40,41,41,41,41,29,29,42,
42,42,42,42,42,47,43,48,43,45,
45,45,45,49,49,49,49,49,49,49,
50,11,11,52,52,52,52,52,53,53,
53,54,54,54,17,17,55,55,56,56,
56,56,56,56,56,56,60,61,60,62,
62,63,57,64,57,59,59,59,59,4,
25,25,25,66,66,66,66,66,35,35,
67,67,37,37,69,69,72,70,73,70,
74,74,74,74,75,75,76,76,39,39,
58,58,79,58,80,58,78,78,78,78,
78,78,81,81,83,84,82,85,85,86,
86,87,87,7,7,46,46,65,65,8,
8,8,8,8,77,77,89,89,89,91,
92,92,93,93,93,93,93,93,93,93,
93,93,93,93,93,93,93,93,93,93,
88,88,95,95,95,95,95,95,2,2,
2,2,51,51,44,98,98,98,98,98,
98,98,98,98,98,98,98,98,98,98,
98,98,99,99,99,94,97,97,100,100,
100,100,100,100,101,101,68,68,68,68,
102,102,102,103,103,104,104,104,105,106,
106,106,106,106,106,106,106,106,106,106,
106,106,106,106,106,106,106,106,28,28,
14,14,90,90,90,90,0,0,31,31,
13,13,13,13,13,13,96,96,6,6,
34,34,34,34,34,34,34,34,34,34,
34,34,34,71,71,71,71
};
short yylen[]={2,
1,1,2,2,3,1,2,3,3,4,
4,2,2,1,3,1,1,1,1,4,
0,1,3,4,1,3,1,3,0,4,
1,1,1,3,2,5,5,6,5,6,
7,3,3,4,3,4,5,2,3,1,
1,1,3,1,3,1,4,6,7,3,
5,2,4,5,7,2,3,3,4,1,
5,4,1,2,2,1,1,1,2,1,
2,1,2,3,1,0,4,0,5,1,
2,2,3,1,3,4,4,4,2,2,
4,1,3,5,6,4,5,2,1,2,
3,1,3,1,1,3,1,3,1,1,
1,1,1,1,1,1,3,0,5,1,
2,0,3,0,4,6,8,10,12,6,
0,1,4,1,3,3,3,4,1,3,
1,3,2,3,1,2,0,4,0,3,
3,6,2,5,1,2,1,3,1,3,
3,3,0,4,0,4,4,4,6,1,
1,3,1,1,0,0,6,0,1,0,
1,0,1,0,1,0,2,0,1,0,
1,1,1,3,1,3,1,3,3,1,
1,3,1,1,1,1,3,3,4,4,
4,3,3,3,3,2,1,1,1,1,
1,3,1,2,2,3,2,3,1,2,
2,3,1,3,3,1,1,1,1,1,
1,1,1,1,1,1,1,1,1,1,
1,1,1,2,3,4,1,3,5,5,
4,2,2,2,0,1,1,2,4,5,
2,2,1,2,3,1,2,3,1,2,
1,3,4,3,5,7,5,5,7,9,
3,2,2,2,3,1,1,1,1,2,
1,2,1,3,3,3,1,2,1,2,
1,1,1,1,1,4,1,2,1,2,
1,2,2,2,2,2,2,2,2,2,
4,4,2,1,1,1,1
};
short yydefred[]={0,
94,321,80,322,0,76,0,0,0,0,
31,123,0,325,0,32,0,0,0,0,
124,0,0,0,82,0,121,120,0,0,
77,132,0,324,317,119,122,125,126,0,
0,0,0,0,0,0,199,0,0,210,
211,0,0,344,347,346,262,246,247,248,
249,250,251,252,253,254,255,256,257,258,
259,260,261,0,0,0,165,0,0,345,
0,241,327,0,329,0,0,318,0,0,
92,0,81,74,0,83,0,0,75,0,
0,0,0,99,100,274,127,0,0,0,
114,0,109,0,0,283,0,0,0,0,
277,0,0,213,214,311,0,0,216,0,
0,0,0,0,0,0,0,0,0,0,
0,0,185,0,14,0,0,115,27,0,
227,0,56,0,230,0,0,0,228,0,
0,0,229,243,0,245,0,163,0,0,
0,0,0,0,166,171,0,172,0,242,
328,330,0,95,93,0,0,0,84,0,
0,88,85,0,0,130,78,0,133,0,
151,0,201,0,0,0,231,0,0,73,
313,195,0,0,0,0,106,110,0,0,
0,0,278,0,282,0,284,271,0,281,
0,0,0,340,332,0,0,0,76,0,
0,0,0,0,0,0,0,0,0,0,
307,0,0,35,0,0,0,0,291,306,
0,309,289,343,336,338,339,337,334,335,
333,0,0,0,0,0,312,0,326,0,
29,0,0,0,0,0,0,0,0,0,
0,0,0,0,226,0,0,0,0,212,
16,17,19,0,18,0,33,0,0,0,
0,320,0,0,0,161,0,182,174,176,
96,0,153,0,0,0,87,135,0,66,
0,0,0,131,79,86,0,0,98,0,
0,0,235,0,0,237,97,129,0,104,
113,107,111,269,270,0,0,287,0,285,
0,0,51,52,50,0,0,0,263,0,
0,0,0,0,308,0,0,0,0,0,
303,302,304,0,0,48,42,0,0,43,
0,310,45,0,290,217,0,218,0,15,
116,28,0,0,0,0,0,0,244,0,
0,0,0,0,314,316,315,224,225,222,
223,117,0,0,0,0,0,0,0,0,
0,0,6,0,0,0,0,0,0,0,
12,13,4,0,0,154,61,0,0,0,
144,197,89,67,68,0,20,236,238,152,
204,232,0,0,105,279,0,288,0,0,
22,136,0,342,341,264,266,0,101,292,
0,0,0,0,0,0,294,305,301,49,
0,0,0,44,46,0,0,57,0,30,
72,0,221,0,220,219,0,34,140,164,
0,8,7,9,5,0,0,0,0,0,
0,0,149,69,280,0,0,0,0,53,
265,0,0,0,0,0,293,36,37,0,
39,0,47,0,159,0,155,0,0,71,
118,143,179,11,10,162,65,145,146,0,
147,0,23,0,137,0,298,0,0,297,
38,40,0,0,58,0,156,0,157,187,
148,150,24,0,0,0,0,0,41,59,
0,0,0,0,138,296,299,0,0,0,
0,0,0,139,300
};
short yydgoto[]={22,
433,23,314,24,434,86,209,204,105,144,
145,304,83,146,470,471,331,594,148,149,
150,403,26,306,307,151,256,257,195,364,
365,366,152,153,522,27,188,259,154,212,
197,198,30,31,32,327,190,329,33,155,
156,34,112,113,424,35,36,37,260,39,
108,199,100,191,48,523,205,118,546,547,
76,592,576,77,78,157,158,79,177,179,
549,159,275,499,367,261,425,206,160,161,
51,52,162,163,207,171,164,80,370,40,
120,121,122,227,262,263
};
short yysindex[]={2403,
0,0,0,0, -60,0, -53,158, -217,62,
0,0, -136,0,111,0,1093,1093,273, -9,
0,2403, -14, -30,0, -90,0,0,343,118,
0,0,41,0,0,0,0,0,0, -122,
65,95, -109,105,113,369,0,212,2390,0,
0,179,218,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0, -3,914,216,0,2838,221,0,
277,0,0,273,0,101,325,0, -30,41,
0,37,0,0,688,0,0, -30,0,565,
327,1364,2390,0,0,0,0,2403, -109,349,
0,115,0,369,369,0,402,773,432,291,
0,180,2390,0,0,0,418,2488,0,2390,
419,424,629,2390,2390,2390,2390,2390,2390,2390,
2390,1927,0,427,0,211,338,0,0, -40,
0,384,0, -41,0, -173,189,364,0, -4,
169,83,0,0, -136,0,1450,0,914,461,
237,4,225,216,0,0,387,0,387,0,
0,0,473,0,0,267,970,471,0,469,
565,0,0,748,565,0,0,343,0,272,
0,914,0,494,503,514,0,390,478,0,
0,0,875,143,2390, -56,0,0,437,463,
329,549,0,2390,0,532,0,0,19,0,
377,2022,1927,0,0,1995,914,533,0,555,
558,1824,561,563,2390,551,553,559,684,360,
0,2390,363,0,5,42,1285,825,0,0,
566,0,0,0,0,0,0,0,0,0,
0,351,586,587,2390,2390,0,2390,0,2390,
0,2390,2390,2255,2390,2390,2390,2390,2390,2390,
2390,2390,2390,2390,0, -32,123,2318,2390,0,
0,0,0,589,0,376,0,593,3957,3,
2390,0,14,87, -31,0,914,0,0,0,
0,519,0,1344,519,2208,0,0,469,0,
595,1395,927,0,0,0,10,390,0,391,
1609, -27,0,25,6,0,0,0, -45,0,
0,0,0,0,0,608,393,0,2390,0,
272,594,0,0,0,612,619,620,0,1182,
624,1824,2390,2390,0,395,2390,2390,610,1824,
0,0,0,274,616,0,0,420,1122,0,
8,0,0,1490,0,0,2333,0,595,0,
0,0,2390,427,189,2390,106,388,0,364,
384,354,169,169,0,0,0,0,0,0,
0,0,637,636,640,31,2390,1450,641,426,
216,3283,0,643,46,592,87, -31,1364,2390,
0,0,0,645,632,0,0,644,438,2208,
0,0,0,0,0,1558,0,0,0,0,
0,0, -15,6,0,0,653,0, -6,381,
0,0,2022,0,0,0,0,647,0,0,
392,416,658,642,425,1824,0,0,0,0,
22,1661,1021,0,0,24,2208,0,3990,0,
0,2390,0,2390,0,0,435,0,0,0,
422,0,0,0,0,662,614,451,519,2390,
2390,48,0,0,0,2390,272,272,650,0,
0,1824,1824,2390,2390,1824,0,0,0,54,
0,1756,0,69,0,3990,0,652,618,0,
0,0,0,0,0,0,0,0,0,2090,
0,448,0,382,0,442,0,459,654,0,
0,0,73,2193,0,2390,0,652,0,0,
0,0,0,272,655,1824,657,2390,0,0,
595,2390,211,474,0,0,0,677,595,272,
660,1824,211,0,0
};
short yyrindex[]={0,
0,0,0,0,1076,0,0,0,681,0,
0,0,0,0,0,0,0,0, -24,0,
0,0,0,0,0,0,0,0,0,0,
0,0,2653,0,0,0,0,0,0,2378,
2459,2138,0,2507,2585,598,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0, -17,0,59,602,0,
609,0,0, -12,0,0,0,0,0,2678,
0,483,0,0,0,0,2594,0,0,0,
0,690,646,0,0,0,0,0,0,357,
0,0,0,598,598,0,0,611,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,676,0,0,0,0,0,0,0,
0,0,0,3572,0,2773,0,0,0,2963,
0,3673,0,4054,0,3413,3927,3765,0,3223,
3033,2864,0,0,0,0,509,0,0,0,
511,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,506,0,279,
0,0,0,676,0,0,0,0,0,0,
0,0,0,0,696,697,0,516,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,302,0,0,0,0,
0,700,0,0,0,0,0,1597,0,0,
0,676,0,0,0,0,0,0,0,0,
0,144,0,0,683,0,676,676,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,705,0,0,
0,0,0,522,0,0,0,0,0,0,
646,0,529,531,0,0,0,0,0,0,
0,554,0,0,0,0,0,0,279,0,
112,676,676,0,0,0,0,537,0,0,
0,0,0,529,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,
475,0,0,0,0,712,0,0,0,0,
0,676,0,0,0,0,676,0,0,676,
0,0,0,0,0,0,0,0,676,0,
683,0,0,676,0,0,0,0,4090,0,
0,0,0,3605,4021,0,0,3483,0,3863,
3732,3314,3122,3155,0,0,0,0,0,0,
0,0,0,715,0,0,0,509,0,0,
66,96,0,0,0,0,539,0,690,646,
0,0,0,0,579,0,0,1597,0,0,
0,0,0,0,0,676,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,676,0,0,0,0,
683,676,676,0,0,683,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,475,0,0,
0,676,676,0,676,676,0,0,0,683,
0,676,0,0,0,664,0,665,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,1216,0,0,0,0,
0,0,683,0,0,0,0,0,0,0,
0,0,0,0,0,676,0,718,0,0,
1718,0,541,0,0,0,0,0,1890,0,
0,676,543,0,0
};
short yygindex[]={661, -
152, -1, -202,49,0, -198, -271,321, -256,479,
489,0,1, -196,248,250, -49,0,72, -89,
162,0,0,0,350,0,0, -187, -95,310,
299,0,504,666,298,0, -235,464,0, -70,
2,136,0,0,33,467,0,0, -18,0,
512,0,689, -76,372,51,0,0,183,0,
0,613,0,0,0, -218,0,622,0,254, -
75,0,0, -72,492,523,525,795,0,0,
0,0,0,0,0, -322,0,0,528,29,
649,0,0,0,482, -11,538,0,0,0,
239, -68,0,596, -25,0
};

short yytable[]={147,
25,28,174,337,90,175,332,84,310,20,
19,19,342,210,19,239,239,82,312,239,
281,284,25,28,342,20,19,240,240,96,
20,240,19,526,119,218,169,258,290,436,
291,180,310,317,19,342,47,19,278,223,
457,278,87,310,484,343,91,442,20,311,
19,97,41,311,342,278,239,278,352,43,
394,89,88,231,278,311,224,95,240,465,
102,104,180,255,181,310,445,19,106,447,
208,560,272,311,186,189,311,278,333,388,
25,49,119,119,311,180,119,452,25,28,
437,435,574,285,286,311,278,181,183,181,
50,185,298,506,177,210,439,91,297,387,
192,103,494,25,210,29,311,218,104,353,
20,437,19,463,351,456,538,110,543,278,
53,226,191,358,178,210,111,29,216,187,
369,98,443,502,469,389,92,305,517,313,
191,181,561,299,379,119,99,440,571,15,
442,181,38,272,325,458,349,325,177,107,
338,25,443,575,25,25,335,589,96,384,
110,492,325,42,38,293,344,391,181,111,
292,110,569,25,28,294,376,109,178,315,
111,210,165,229,418,399,1,114,419,1,
336,392,239,431,407,115,85,166,230,217,
346,1,1,29,240,280,95,1,182,426,
283,123,277,168,85,223,345,167,25,335,
316,226,1,88,211,598,85,350,277,210,
15,15,353,172,15,1,310,239,19,176,
46,1,513,557,289,515,15,15,468,240,
38,235,15,493,478,264,265,266,267,268,
269,270,271,363,15,542,392,15,313,182,
513,515,119,313,19,15,501,278,413,414,
15,101,196,481,482,90,15,311,485,208,
469,469,488,25,335,178,344,196,181,491,
344,582,15,344,496,286,480,15,29,401,
210,402,219,220,487,582,174,1,315,175,
286,438,441,315,182,184,200,101,392,422,
459,110,295,170,87,296,211,91,279,420,
111,278,20,421,19,211,345,593,15,25,
345,396,464,345,278,38,290,451,291,110,
112,94,15,603,325,325,211,325,111,215,
325,325,550,264,44,228,429,362,45,428,
278,529,585,548,527,527,325,208,305,342,
392,19,532,313,361,278,313,211,528,584,
273,221,540,211,211,325,211,211,211,211,
211,211,211,415,416,417,533,232,236,278,
537,344,344,237,276,536,392,308,278,277,
578,20,211,19,500,552,562,282,504,287,
311,112,62,315,568,441,315,288,583,224,
225,278,573,25,335,183,185,2,422,587,
4,309,278,7,8,60,566,567,318,194,
570,345,345,321,601,21,392,600,21,10,
211,451,62,322,62,62,591,62,325,326,
126,368,21,2,339,371,4,14,15,7,
8,62,599,62,363,60,340,60,60,141,
60,319,141,63,319,10,233,341,498,233,
596,354,142,196,60,142,60,211,451,1,
347,2,1,14,2,551,605,234,64,3,
234,25,3,26,25,356,26,355,357,359,
372,558,559,63,373,63,63,374,63,1,
377,211,378,2,93,274,4,62,380,7,
8,381,63,112,63,444,385,382,64,386,
64,64,112,64,395,10,397,398,427,2,
60,451,4,430,116,7,8,64,278,64,
319,187,320,14,15,451,1,460,466,467,
2,10,472,4,196,473,7,8,334,474,
475,139,117,211,479,483,135,486,142,14,
138,136,10,137,489,286,490,503,63,504,
505,509,510,512,514,518,253,194,1,519,
14,15,2,525,521,4,274,534,7,8,
535,520,554,64,531,553,555,556,565,579,
580,586,588,595,10,597,139,602,604,143,
198,135,275,142,173,138,136,20,137,19,
200,175,14,15,190,276,202,203,194,62,
188,191,383,62,62,192,62,62,62,62,
62,194,189,254,140,193,184,183,190,516,
404,423,60,62,400,62,60,60,213,60,
60,60,60,60,143,564,563,508,62,62,
139,62,530,62,62,135,60,142,60,138,
136,411,137,234,544,453,408,214,507,577,
432,60,60,328,60,405,60,60,324,140,
63,410,81,300,63,63,412,63,63,63,
63,63,462,409,360,2,3,0,4,193,
6,7,8,0,63,64,63,0,143,64,
64,0,64,64,64,64,64,10,0,63,
63,0,63,0,63,63,0,139,0,64,
0,64,135,13,142,14,138,136,0,137,
194,0,330,140,64,64,0,64,0,64,
64,0,0,0,0,238,125,126,127,2,
3,0,4,193,239,7,8,240,0,241,
242,243,244,245,246,247,248,249,250,9,
128,10,129,251,20,143,19,17,130,18,
0,0,0,131,0,0,132,13,133,252,
0,141,0,21,0,16,0,0,0,0,
124,125,126,127,1,0,0,194,2,393,
140,4,0,0,7,8,0,0,0,139,
0,0,0,0,135,128,142,129,138,136,
10,137,0,130,0,0,0,0,131,0,
0,132,0,133,134,0,141,0,14,15,
0,0,0,0,0,0,0,0,0,348,
0,0,0,0,238,125,126,127,2,3,
0,4,193,239,7,8,240,143,241,242,
243,244,245,246,247,248,249,250,9,128,
10,129,251,2,0,0,4,130,116,7,
8,0,131,0,0,132,13,133,252,194,
141,455,140,139,0,10,0,0,135,0,
142,0,138,136,0,137,222,0,0,0,
0,0,0,14,0,0,0,0,0,0,
0,238,125,126,127,2,3,0,4,193,
239,7,8,240,323,241,242,243,244,245,
246,247,248,249,250,9,128,10,129,251,
0,143,0,0,130,85,0,85,0,131,
0,0,132,13,133,252,0,141,0,0,
0,1,75,0,85,2,3,0,4,5,
6,7,8,194,0,541,140,0,0,0,
74,0,0,0,139,9,0,10,0,135,
0,142,0,138,136,0,137,0,0,0,
11,12,0,13,2,14,15,4,0,0,
7,8,0,238,125,126,127,2,3,0,
4,193,239,7,8,240,10,241,242,243,
244,245,246,247,248,249,250,9,128,10,
129,251,143,0,14,0,130,0,0,0,
0,131,477,0,132,13,133,252,0,141,
2,0,0,4,0,116,7,8,0,476,
0,0,0,0,194,0,0,140,295,0,
0,0,10,295,0,295,0,295,295,0,
295,0,0,117,0,0,0,0,0,0,
14,0,0,0,295,0,0,238,125,126,
127,2,3,0,4,193,239,7,8,240,
0,241,242,243,244,245,246,247,248,249,
250,9,128,10,129,251,295,0,0,0,
130,0,0,0,0,131,0,139,132,13,
133,252,135,141,142,0,138,136,0,137,
0,0,85,0,0,0,85,85,295,85,
295,295,85,85,0,0,0,0,0,54,
0,0,55,56,0,0,57,0,85,58,
59,60,61,62,63,64,65,66,67,68,
69,70,71,72,73,143,85,85,238,125,
126,127,2,3,0,4,193,239,7,8,
240,0,241,242,243,244,245,246,247,248,
249,250,9,128,10,129,251,194,0,390,
140,130,0,0,0,0,131,0,0,132,
13,133,252,0,141,0,0,139,0,0,
0,0,135,0,142,0,138,136,54,137,
0,55,56,0,0,57,0,0,58,59,
60,61,62,63,64,65,66,67,68,69,
70,71,72,73,0,0,0,0,446,0,
0,0,295,295,295,295,0,0,0,0,
0,295,0,0,295,143,295,295,295,295,
295,295,295,295,295,295,295,295,0,295,
295,0,0,0,0,295,0,0,0,0,
295,0,0,295,0,295,295,194,295,454,
140,0,139,0,0,0,0,135,0,142,
0,138,136,0,137,0,0,0,0,0,
0,238,125,126,127,0,0,0,0,0,
375,0,0,240,0,241,242,243,244,245,
246,247,248,249,250,9,128,0,129,251,
0,0,0,0,130,0,0,0,0,131,
143,0,132,0,133,134,0,141,0,0,
139,0,0,0,0,135,0,142,0,138,
136,0,137,0,2,0,0,4,0,116,
7,8,194,0,495,140,0,0,0,0,
201,0,0,0,2,202,10,4,0,0,
7,8,0,213,213,0,213,222,213,213,
213,213,213,213,14,0,10,203,143,0,
0,238,125,126,127,213,0,213,0,213,
375,0,0,240,14,241,242,243,244,245,
246,247,248,249,250,9,128,0,129,251,
194,0,524,140,130,0,0,213,0,131,
213,0,132,139,133,134,0,141,135,0,
142,0,138,136,0,137,301,0,0,0,
2,302,0,303,0,0,7,8,0,0,
213,213,0,0,0,0,0,0,0,0,
0,0,10,0,0,0,0,0,0,0,
0,0,0,0,0,0,238,125,126,127,
14,143,0,0,0,375,0,0,240,0,
241,242,243,244,245,246,247,248,249,250,
9,128,0,129,251,160,0,0,0,130,
0,0,0,194,131,539,140,132,139,133,
134,0,141,135,0,142,0,138,136,0,
137,0,0,0,0,0,0,0,0,0,
160,0,0,0,238,125,126,127,0,0,
0,0,0,375,0,0,240,0,241,242,
243,244,245,246,247,248,249,250,9,128,
0,129,251,0,0,0,143,130,0,0,
0,0,131,0,0,132,139,133,134,0,
141,135,0,142,0,138,136,0,137,2,
202,0,4,0,0,7,8,0,194,0,
572,140,213,213,213,213,213,213,213,213,
0,10,461,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,14,
0,0,0,0,143,0,0,238,125,126,
127,0,0,0,0,0,375,0,0,240,
0,241,242,243,244,245,246,247,248,249,
250,9,128,0,129,251,194,158,0,140,
130,0,0,0,0,131,0,0,132,139,
133,134,0,141,135,0,142,0,138,136,
0,137,0,0,160,0,0,160,160,0,
0,160,158,0,160,160,160,160,160,160,
160,160,160,160,160,160,160,160,160,160,
0,0,0,0,0,0,0,0,0,0,
0,0,238,125,126,127,0,143,0,0,
0,375,0,0,240,0,241,242,243,244,
245,246,247,248,249,250,9,128,0,129,
251,0,0,0,0,130,0,0,0,194,
131,0,140,132,139,133,134,0,141,135,
0,142,0,138,136,0,137,0,0,0,
0,0,0,0,0,0,0,0,0,0,
238,125,126,127,0,0,0,0,0,375,
0,0,240,0,241,242,243,244,245,246,
247,248,249,250,9,128,0,129,251,0,
0,0,143,130,0,0,0,0,131,0,
0,132,139,133,134,0,141,135,0,142,
0,138,136,0,137,449,0,0,0,0,
0,0,0,0,0,0,158,140,0,158,
158,0,0,158,0,0,158,158,158,158,
158,158,158,158,158,158,158,158,158,158,
158,158,0,0,0,0,0,108,108,108,
143,108,0,124,125,126,127,2,0,0,
4,0,0,7,8,108,108,0,0,0,
0,0,0,0,0,0,0,0,128,10,
129,0,450,0,581,140,130,0,0,0,
0,131,0,0,132,139,133,252,108,141,
135,0,142,0,138,136,0,137,449,0,
139,0,0,0,0,135,0,142,0,138,
136,54,137,449,55,56,0,0,57,0,
0,58,59,60,61,62,63,64,65,66,
67,68,69,70,71,72,73,0,124,125,
126,127,2,143,0,4,0,139,7,8,
0,0,135,0,142,0,138,136,143,137,
0,0,0,128,10,129,0,0,0,0,
0,130,406,0,0,450,131,590,140,132,
0,133,252,0,141,0,0,0,0,0,
450,0,0,140,0,0,0,0,0,0,
0,0,0,0,0,143,448,125,126,127,
139,0,0,0,0,135,0,142,0,138,
136,0,137,0,0,139,0,0,0,0,
135,128,142,129,138,136,0,137,0,130,
140,0,0,0,131,0,0,132,0,133,
134,0,141,0,108,0,0,0,108,108,
0,108,0,0,108,108,0,0,143,0,
0,0,0,0,0,0,0,323,323,323,
108,323,139,143,0,0,0,135,0,142,
0,138,136,0,137,323,323,0,108,108,
194,0,20,140,19,17,0,18,0,448,
125,126,127,0,0,497,0,0,140,0,
0,21,0,16,448,125,126,127,323,0,
0,0,0,0,128,0,129,0,0,0,
143,0,130,0,0,0,0,131,0,128,
132,129,133,134,0,141,0,130,128,0,
128,128,131,128,0,132,0,133,134,0,
141,124,125,126,127,140,0,128,0,128,
139,0,0,0,0,135,0,233,0,138,
136,0,137,0,0,0,128,0,129,0,
0,0,0,0,130,0,272,272,272,131,
272,0,132,0,133,134,0,141,0,0,
0,0,0,0,272,272,0,0,0,0,
0,0,0,0,124,125,126,127,143,0,
0,0,0,0,0,0,0,0,0,124,
125,126,127,0,0,0,0,272,0,128,
0,129,0,0,0,0,0,130,0,0,
0,0,131,140,128,132,129,133,134,0,
141,0,130,0,273,273,273,131,273,0,
132,0,133,134,323,141,0,86,323,323,
0,323,273,273,323,323,124,125,126,127,
0,0,86,0,86,0,0,0,0,1,
323,0,0,2,3,0,4,5,6,7,
8,128,0,129,0,273,0,0,323,130,
0,0,0,9,131,10,0,132,0,133,
134,0,141,90,0,0,90,0,11,12,
0,13,0,14,15,0,0,0,0,0,
90,90,0,90,0,128,134,0,91,128,
128,91,128,128,128,128,128,0,0,0,
0,0,0,0,0,91,91,0,91,128,
0,128,0,0,124,125,126,127,0,0,
0,0,0,0,128,128,0,128,0,128,
128,0,0,272,0,0,0,272,272,128,
272,129,0,272,272,90,0,130,0,0,
0,0,131,0,0,132,0,133,134,272,
141,0,0,0,0,0,0,0,0,0,
91,0,0,0,0,0,0,272,272,215,
215,0,215,215,215,215,215,215,215,215,
0,0,0,0,0,0,0,0,0,0,
215,215,0,215,0,215,0,0,0,0,
0,273,0,0,0,273,273,0,273,0,
0,273,273,0,134,134,0,134,134,134,
134,134,0,215,0,215,215,273,0,0,
0,0,0,0,0,0,134,0,0,0,
0,173,0,0,0,273,273,0,0,0,
0,0,134,0,134,74,215,215,0,0,
331,331,0,0,331,331,331,331,331,0,
331,0,0,90,90,0,90,90,90,90,
90,331,331,0,331,0,331,0,0,0,
0,0,0,0,0,90,0,0,91,91,
0,91,91,91,91,91,0,0,0,0,
0,90,0,90,0,0,331,331,0,0,
91,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,91,0,91,0,
0,0,0,0,0,0,0,331,331,0,
0,0,0,0,0,0,0,0,0,313,
313,0,0,313,313,313,313,313,0,313,
0,0,0,0,0,0,0,0,0,0,
313,313,0,0,0,313,0,0,0,215,
0,0,215,215,0,0,215,0,215,215,
215,215,215,215,215,215,215,215,215,215,
215,215,215,215,215,313,313,0,215,215,
215,215,215,215,215,215,0,0,0,0,
207,0,0,207,0,207,207,207,0,0,
0,0,0,0,0,0,313,313,0,0,
207,207,0,0,54,207,0,55,56,0,
0,57,0,0,58,59,60,61,62,63,
64,65,66,67,68,69,70,71,72,73,
331,0,0,331,331,207,207,331,0,331,
331,331,331,331,331,331,331,331,331,331,
331,331,331,331,331,331,0,0,0,331,
331,331,331,0,331,331,207,207,0,208,
0,0,208,0,208,208,208,0,0,0,
0,0,0,0,0,0,0,0,0,208,
208,0,0,0,208,0,0,0,0,0,
0,0,209,0,0,209,0,209,209,209,
0,0,0,0,0,0,0,0,0,0,
0,0,209,209,208,208,0,209,0,313,
0,0,313,313,0,0,313,0,0,313,
313,313,313,313,313,313,313,313,313,313,
313,313,313,313,313,208,208,209,209,313,
313,313,0,313,313,0,0,0,0,0,
267,0,0,267,0,0,267,0,0,0,
0,0,0,0,0,0,0,0,209,209,
267,267,0,0,0,267,0,0,0,207,
0,0,207,207,0,0,207,0,207,207,
207,207,207,207,207,207,207,207,207,207,
207,207,207,207,207,267,267,0,0,207,
207,207,0,207,207,0,511,0,0,0,
0,0,0,0,0,0,0,0,0,0,
74,0,0,0,0,0,267,267,0,0,
0,268,0,0,268,0,0,268,0,0,
0,0,0,0,0,0,0,0,0,0,
0,268,268,0,0,0,268,0,208,0,
0,208,208,0,0,208,0,208,208,208,
208,208,208,208,208,208,208,208,208,208,
208,208,208,208,0,0,268,268,208,208,
208,209,208,208,209,209,0,0,209,0,
209,209,209,209,209,209,209,209,209,209,
209,209,209,209,209,209,209,268,268,0,
0,209,209,209,0,209,209,0,0,0,
102,0,0,102,0,0,102,0,0,0,
0,0,0,0,0,0,0,0,0,0,
102,102,0,0,0,102,0,0,0,267,
0,0,267,267,0,0,267,0,267,267,
267,267,267,267,267,267,267,267,267,267,
267,267,267,267,267,102,102,0,0,267,
267,0,0,267,267,0,0,0,0,0,
103,0,0,103,0,0,103,0,0,0,
0,0,0,0,0,0,102,102,0,54,
103,103,55,56,0,103,57,0,0,58,
59,60,61,62,63,64,65,66,67,68,
69,70,71,72,73,0,0,0,0,0,
268,0,0,268,268,103,103,268,0,268,
268,268,268,268,268,268,268,268,268,268,
268,268,268,268,268,268,0,0,0,0,
268,268,0,0,268,268,103,103,0,0,
0,0,54,0,0,54,0,0,0,0,
0,0,0,0,0,0,0,0,0,54,
54,0,0,0,54,0,0,0,0,0,
0,0,0,0,0,55,0,0,55,0,
0,0,0,0,0,0,0,0,0,0,
0,0,55,55,54,54,0,55,0,102,
0,0,102,102,0,0,102,0,102,102,
102,102,102,102,102,102,102,102,102,102,
102,102,102,102,102,54,54,55,55,0,
0,0,0,102,102,0,0,0,0,0,
0,0,0,205,0,0,205,0,0,0,
0,0,0,0,0,0,0,0,55,55,
205,205,0,0,0,205,0,0,0,103,
0,0,103,103,0,0,103,0,103,103,
103,103,103,103,103,103,103,103,103,103,
103,103,103,103,103,205,0,0,0,0,
0,0,206,103,103,206,0,0,0,0,
0,0,0,0,0,0,0,0,0,206,
206,0,0,0,206,0,205,205,0,0,
0,0,0,0,0,167,0,0,167,0,
0,0,0,0,0,0,0,0,0,0,
0,0,167,167,206,0,0,167,54,0,
0,54,54,0,0,54,0,54,54,54,
54,54,54,54,54,54,54,54,54,54,
54,54,54,54,0,206,206,167,0,0,
0,55,54,54,55,55,0,0,55,0,
55,55,55,55,55,55,55,55,55,55,
55,55,55,55,55,55,55,0,0,167,
0,0,0,0,0,55,55,0,0,0,
0,0,0,168,0,0,168,0,0,0,
0,0,0,0,0,0,0,0,0,0,
168,168,0,0,0,168,0,0,0,205,
0,0,205,205,0,0,205,0,205,205,
205,205,205,205,205,205,205,205,205,205,
205,205,205,205,205,168,0,0,0,0,
0,0,0,205,205,0,0,169,0,0,
169,0,0,0,0,0,0,0,0,0,
0,0,0,0,169,169,0,168,206,169,
0,206,206,0,0,206,0,206,206,206,
206,206,206,206,206,206,206,206,206,206,
206,206,206,206,74,0,0,0,0,169,
0,167,206,206,167,167,0,0,167,0,
167,167,167,167,167,167,167,167,167,167,
167,167,167,167,167,167,167,545,0,0,
0,169,0,0,0,167,167,0,0,0,
0,170,0,0,170,0,0,0,0,0,
0,0,0,0,0,0,0,0,170,170,
0,0,0,170,0,0,0,0,0,0,
0,0,0,0,70,0,0,70,0,0,
0,0,0,0,0,0,0,0,0,0,
0,70,70,170,0,0,0,0,0,168,
0,0,168,168,0,0,168,0,168,168,
168,168,168,168,168,168,168,168,168,168,
168,168,168,168,168,170,70,186,0,0,
0,0,0,168,168,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,70,0,
0,0,0,169,0,0,169,169,0,0,
169,0,169,169,169,169,169,169,169,169,
169,169,169,169,169,169,169,169,169,0,
0,0,0,54,0,0,55,56,169,0,
57,0,0,58,59,60,61,62,63,64,
65,66,67,68,69,70,71,72,73,0,
0,0,0,0,0,0,54,0,0,55,
56,0,0,57,0,0,58,59,60,61,
62,63,64,65,66,67,68,69,70,71,
72,73,0,0,0,0,0,170,0,0,
170,170,0,0,170,0,170,170,170,170,
170,170,170,170,170,170,170,170,170,170,
170,170,170,0,0,0,0,0,0,0,
70,0,170,70,70,0,0,70,0,70,
70,70,70,70,70,70,70,70,70,70,
70,70,70,70,70,70,0,0,0,0,
0,0,0,0,0,0,186,0,0,186,
186,0,0,186,0,0,186,186,186,186,
186,186,186,186,186,186,186,186,186,186,
186,186
};
short yycheck[]={49,
0,0,78,200,23,78,194,19,40,40,
42,42,40,103,42,40,41,19,171,44,
61,63,22,22,40,40,42,40,41,29,
40,44,42,40,46,112,40,133,43,311,
45,59,40,40,42,40,264,42,44,118,
41,44,20,40,377,208,24,314,40,91,
42,29,123,91,40,44,91,44,125,123,
258,23,22,123,44,91,58,29,91,125,
40,33,84,133,84,40,322,42,40,325,
102,44,142,91,58,95,91,44,194,58,
100,40,114,115,91,123,118,326,108,108,
313,310,44,287,288,91,44,59,86,119,
257,89,40,93,59,215,40,95,46,125,
98,91,125,133,224,0,91,214,90,216,
40,344,42,342,215,333,125,257,125,44,
40,119,41,224,59,245,266,22,44,123,
236,44,315,58,361,124,257,167,440,171,
59,171,125,91,245,187,59,91,125,302,
437,123,0,233,41,338,44,44,123,125,
202,191,345,125,194,195,195,125,198,249,
257,389,59,257,22,37,208,257,208,266,
42,257,535,213,213,47,242,123,123,171,
266,311,44,44,257,275,257,123,261,257,
198,257,257,309,284,123,264,59,59,125,
208,257,257,108,257,286,198,257,264,299,
292,40,259,257,264,324,208,40,258,258,
257,229,257,213,103,588,264,125,259,359,
302,302,349,58,302,257,40,302,42,59,
123,257,435,519,289,438,302,302,359,302,
108,130,302,389,370,134,135,136,137,138,
139,140,141,232,302,493,332,302,310,264,
463,464,324,315,42,302,406,44,290,291,
302,281,44,373,374,344,302,91,378,341,
527,528,59,333,333,59,338,59,338,389,
342,560,302,345,394,44,372,302,213,278,
440,280,114,115,380,574,432,257,310,432,
59,313,314,315,264,41,40,281,394,298,
338,257,290,75,342,293,215,345,41,257,
266,44,40,261,42,224,338,584,302,389,
342,41,344,345,44,213,43,326,45,257,
44,59,302,600,261,262,245,264,266,61,
267,268,502,252,257,125,41,41,261,44,
44,41,41,499,44,44,283,439,428,40,
456,42,41,435,58,44,438,276,58,58,
142,40,492,282,283,302,285,286,287,288,
289,290,291,292,293,294,41,40,40,44,
486,463,464,40,38,41,492,169,44,259,
546,40,311,42,403,41,526,94,44,291,
91,125,0,435,534,437,438,124,41,58,
59,44,542,493,493,463,464,261,427,41,
264,41,44,267,268,0,532,533,284,123,
536,463,464,41,41,41,542,44,44,283,
359,450,40,257,42,43,576,45,58,61,
259,233,58,261,41,237,264,301,302,267,
268,59,592,61,473,40,44,42,43,41,
45,41,44,0,44,283,41,44,397,44,
586,125,41,100,59,44,61,406,497,41,
93,41,44,301,44,504,602,41,0,41,
44,41,44,41,44,257,44,125,40,58,
58,520,521,40,40,42,43,40,45,257,
40,440,40,261,262,142,264,125,58,267,
268,59,59,257,61,317,257,59,40,257,
42,43,266,45,59,283,41,41,40,261,
125,560,264,41,266,267,268,59,44,61,
177,123,179,301,302,574,257,257,41,257,
261,283,59,264,191,44,267,268,195,41,
41,33,294,502,41,271,38,58,40,301,
42,43,283,45,59,288,257,41,125,44,
41,41,257,41,93,41,58,123,257,58,
301,302,261,41,257,264,233,40,267,268,
59,58,41,125,58,284,93,257,59,58,
93,270,59,59,283,59,33,41,59,91,
40,38,125,40,123,42,43,40,45,42,
41,123,301,302,59,125,41,41,93,257,
41,59,59,261,262,41,264,265,266,267,
268,123,41,125,126,41,93,93,41,439,
282,298,257,281,276,283,261,262,108,264,
265,266,267,268,91,528,527,428,296,297,
33,299,473,301,302,38,281,40,283,42,
43,288,45,128,497,329,285,109,427,546,
309,296,297,191,299,283,301,302,187,126,
257,287,18,165,261,262,289,264,265,266,
267,268,341,286,229,261,262, -1,264,265,
266,267,268, -1,281,257,283, -1,91,261,
262, -1,264,265,266,267,268,283, -1,296,
297, -1,299, -1,301,302, -1,33, -1,281, -
1,283,38,299,40,301,42,43, -1,45,
123, -1,125,126,296,297, -1,299, -1,301,
302, -1, -1, -1, -1,257,258,259,260,261,
262, -1,264,265,266,267,268,269, -1,271,
272,273,274,275,276,277,278,279,280,281,
282,283,284,285,40,91,42,43,290,45, -
1, -1, -1,295, -1, -1,298,299,300,301, -
1,303, -1,59, -1,61, -1, -1, -1, -1,
257,258,259,260,257, -1, -1,123,261,125,
126,264, -1, -1,267,268, -1, -1, -1,33, -
1, -1, -1, -1,38,282,40,284,42,43,
283,45, -1,290, -1, -1, -1, -1,295, -1, -
1,298, -1,300,301, -1,303, -1,301,302, -
1, -1, -1, -1, -1, -1, -1, -1, -1,125, -
1, -1, -1, -1,257,258,259,260,261,262, -
1,264,265,266,267,268,269,91,271,272,
273,274,275,276,277,278,279,280,281,282,
283,284,285,261, -1, -1,264,290,266,267,
268, -1,295, -1, -1,298,299,300,301,123,
303,125,126,33, -1,283, -1, -1,38, -1,
40, -1,42,43, -1,45,294, -1, -1, -1, -
1, -1, -1,301, -1, -1, -1, -1, -1, -1, -
1,257,258,259,260,261,262, -1,264,265,
266,267,268,269,125,271,272,273,274,275,
276,277,278,279,280,281,282,283,284,285, -
1,91, -1, -1,290,40, -1,42, -1,295, -
1, -1,298,299,300,301, -1,303, -1, -1, -
1,257,40, -1,59,261,262, -1,264,265,
266,267,268,123, -1,125,126, -1, -1, -1,
58, -1, -1, -1,33,281, -1,283, -1,38, -
1,40, -1,42,43, -1,45, -1, -1, -1,
296,297, -1,299,261,301,302,264, -1, -1,
267,268, -1,257,258,259,260,261,262, -1,
264,265,266,267,268,269,283,271,272,273,
274,275,276,277,278,279,280,281,282,283,
284,285,91, -1,301, -1,290, -1, -1, -1, -
1,295,41, -1,298,299,300,301, -1,303,
261, -1, -1,264, -1,266,267,268, -1,58, -
1, -1, -1, -1,123, -1, -1,126,33, -1, -
1, -1,283,38, -1,40, -1,42,43, -1,
45, -1, -1,294, -1, -1, -1, -1, -1, -1,
301, -1, -1, -1,59, -1, -1,257,258,259,
260,261,262, -1,264,265,266,267,268,269, -
1,271,272,273,274,275,276,277,278,279,
280,281,282,283,284,285,91, -1, -1, -1,
290, -1, -1, -1, -1,295, -1,33,298,299,
300,301,38,303,40, -1,42,43, -1,45, -
1, -1,257, -1, -1, -1,261,262,123,264,
125,126,267,268, -1, -1, -1, -1, -1,257, -
1, -1,260,261, -1, -1,264, -1,283,267,
268,269,270,271,272,273,274,275,276,277,
278,279,280,281,282,91,301,302,257,258,
259,260,261,262, -1,264,265,266,267,268,
269, -1,271,272,273,274,275,276,277,278,
279,280,281,282,283,284,285,123, -1,125,
126,290, -1, -1, -1, -1,295, -1, -1,298,
299,300,301, -1,303, -1, -1,33, -1, -1, -
1, -1,38, -1,40, -1,42,43,257,45, -
1,260,261, -1, -1,264, -1, -1,267,268,
269,270,271,272,273,274,275,276,277,278,
279,280,281,282, -1, -1, -1, -1,125, -1, -
1, -1,257,258,259,260, -1, -1, -1, -1, -
1,266, -1, -1,269,91,271,272,273,274,
275,276,277,278,279,280,281,282, -1,284,
285, -1, -1, -1, -1,290, -1, -1, -1, -1,
295, -1, -1,298, -1,300,301,123,303,125,
126, -1,33, -1, -1, -1, -1,38, -1,40, -
1,42,43, -1,45, -1, -1, -1, -1, -1, -
1,257,258,259,260, -1, -1, -1, -1, -1,
266, -1, -1,269, -1,271,272,273,274,275,
276,277,278,279,280,281,282, -1,284,285, -
1, -1, -1, -1,290, -1, -1, -1, -1,295,
91, -1,298, -1,300,301, -1,303, -1, -1,
33, -1, -1, -1, -1,38, -1,40, -1,42,
43, -1,45, -1,261, -1, -1,264, -1,266,
267,268,123, -1,125,126, -1, -1, -1, -1,
257, -1, -1, -1,261,262,283,264, -1, -1,
267,268, -1,37,38, -1,40,294,42,43,
44,45,46,47,301, -1,283,284,91, -1, -
1,257,258,259,260,59, -1,61, -1,63,
266, -1, -1,269,301,271,272,273,274,275,
276,277,278,279,280,281,282, -1,284,285,
123, -1,125,126,290, -1, -1,91, -1,295,
94, -1,298,33,300,301, -1,303,38, -1,
40, -1,42,43, -1,45,257, -1, -1, -1,
261,262, -1,264, -1, -1,267,268, -1, -1,
124,125, -1, -1, -1, -1, -1, -1, -1, -1, -
1, -1,283, -1, -1, -1, -1, -1, -1, -1, -
1, -1, -1, -1, -1, -1,257,258,259,260,
301,91, -1, -1, -1,266, -1, -1,269, -1,
271,272,273,274,275,276,277,278,279,280,
281,282, -1,284,285,58, -1, -1, -1,290, -
1, -1, -1,123,295,125,126,298,33,300,
301, -1,303,38, -1,40, -1,42,43, -1,
45, -1, -1, -1, -1, -1, -1, -1, -1, -1,
93, -1, -1, -1,257,258,259,260, -1, -1, -
1, -1, -1,266, -1, -1,269, -1,271,272,
273,274,275,276,277,278,279,280,281,282, -
1,284,285, -1, -1, -1,91,290, -1, -1, -
1, -1,295, -1, -1,298,33,300,301, -1,
303,38, -1,40, -1,42,43, -1,45,261,
262, -1,264, -1, -1,267,268, -1,123, -1,
125,126,286,287,288,289,290,291,292,293, -
1,283,284, -1, -1, -1, -1, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1,301, -
1, -1, -1, -1,91, -1, -1,257,258,259,
260, -1, -1, -1, -1, -1,266, -1, -1,269, -
1,271,272,273,274,275,276,277,278,279,
280,281,282, -1,284,285,123,58, -1,126,
290, -1, -1, -1, -1,295, -1, -1,298,33,
300,301, -1,303,38, -1,40, -1,42,43, -
1,45, -1, -1,257, -1, -1,260,261, -1, -
1,264,93, -1,267,268,269,270,271,272,
273,274,275,276,277,278,279,280,281,282, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -
1, -1,257,258,259,260, -1,91, -1, -1, -
1,266, -1, -1,269, -1,271,272,273,274,
275,276,277,278,279,280,281,282, -1,284,
285, -1, -1, -1, -1,290, -1, -1, -1,123,
295, -1,126,298,33,300,301, -1,303,38, -
1,40, -1,42,43, -1,45, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
257,258,259,260, -1, -1, -1, -1, -1,266, -
1, -1,269, -1,271,272,273,274,275,276,
277,278,279,280,281,282, -1,284,285, -1, -
1, -1,91,290, -1, -1, -1, -1,295, -1, -
1,298,33,300,301, -1,303,38, -1,40, -
1,42,43, -1,45,46, -1, -1, -1, -1, -
1, -1, -1, -1, -1, -1,257,126, -1,260,
261, -1, -1,264, -1, -1,267,268,269,270,
271,272,273,274,275,276,277,278,279,280,
281,282, -1, -1, -1, -1, -1,40,41,42,
91,44, -1,257,258,259,260,261, -1, -1,
264, -1, -1,267,268,58,59, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1,282,283,
284, -1,123, -1,125,126,290, -1, -1, -1, -
1,295, -1, -1,298,33,300,301,91,303,
38, -1,40, -1,42,43, -1,45,46, -1,
33, -1, -1, -1, -1,38, -1,40, -1,42,
43,257,45,46,260,261, -1, -1,264, -1, -
1,267,268,269,270,271,272,273,274,275,
276,277,278,279,280,281,282, -1,257,258,
259,260,261,91, -1,264, -1,33,267,268, -
1, -1,38, -1,40, -1,42,43,91,45, -
1, -1, -1,282,283,284, -1, -1, -1, -1, -
1,290,58, -1, -1,123,295,125,126,298, -
1,300,301, -1,303, -1, -1, -1, -1, -1,
123, -1, -1,126, -1, -1, -1, -1, -1, -1, -
1, -1, -1, -1, -1,91,257,258,259,260,
33, -1, -1, -1, -1,38, -1,40, -1,42,
43, -1,45, -1, -1,33, -1, -1, -1, -1,
38,282,40,284,42,43, -1,45, -1,290,
126, -1, -1, -1,295, -1, -1,298, -1,300,
301, -1,303, -1,257, -1, -1, -1,261,262, -
1,264, -1, -1,267,268, -1, -1,91, -1, -
1, -1, -1, -1, -1, -1, -1,40,41,42,
283,44,33,91, -1, -1, -1,38, -1,40, -
1,42,43, -1,45,58,59, -1,301,302,
123, -1,40,126,42,43, -1,45, -1,257,
258,259,260, -1, -1,123, -1, -1,126, -1, -
1,59, -1,61,257,258,259,260,91, -1, -
1, -1, -1, -1,282, -1,284, -1, -1, -1,
91, -1,290, -1, -1, -1, -1,295, -1,282,
298,284,300,301, -1,303, -1,290,40, -1,
42,43,295,45, -1,298, -1,300,301, -1,
303,257,258,259,260,126, -1,59, -1,61,
33, -1, -1, -1, -1,38, -1,40, -1,42,
43, -1,45, -1, -1, -1,282, -1,284, -1, -
1, -1, -1, -1,290, -1,40,41,42,295,
44, -1,298, -1,300,301, -1,303, -1, -1, -
1, -1, -1, -1,58,59, -1, -1, -1, -1, -
1, -1, -1, -1,257,258,259,260,91, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1,257,
258,259,260, -1, -1, -1, -1,91, -1,282, -
1,284, -1, -1, -1, -1, -1,290, -1, -1, -
1, -1,295,126,282,298,284,300,301, -1,
303, -1,290, -1,40,41,42,295,44, -1,
298, -1,300,301,257,303, -1,44,261,262, -
1,264,58,59,267,268,257,258,259,260, -
1, -1,59, -1,61, -1, -1, -1, -1,257,
283, -1, -1,261,262, -1,264,265,266,267,
268,282, -1,284, -1,91, -1, -1,301,290, -
1, -1, -1,281,295,283, -1,298, -1,300,
301, -1,303,41, -1, -1,44, -1,296,297, -
1,299, -1,301,302, -1, -1, -1, -1, -1,
58,59, -1,61, -1,257,123, -1,41,261,
262,44,264,265,266,267,268, -1, -1, -1, -
1, -1, -1, -1, -1,58,59, -1,61,281, -
1,283, -1, -1,257,258,259,260, -1, -1, -
1, -1, -1, -1,296,297, -1,299, -1,301,
302, -1, -1,257, -1, -1, -1,261,262,282,
264,284, -1,267,268,123, -1,290, -1, -1, -
1, -1,295, -1, -1,298, -1,300,301,283,
303, -1, -1, -1, -1, -1, -1, -1, -1, -1,
123, -1, -1, -1, -1, -1, -1,301,302,37,
38, -1,40,41,42,43,44,45,46,47, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
58,59, -1,61, -1,63, -1, -1, -1, -1, -
1,257, -1, -1, -1,261,262, -1,264, -1, -
1,267,268, -1,261,262, -1,264,265,266,
267,268, -1,91, -1,93,94,283, -1, -1, -
1, -1, -1, -1, -1, -1,283, -1, -1, -1, -
1,44, -1, -1, -1,301,302, -1, -1, -1, -
1, -1,299, -1,301,58,124,125, -1, -1,
37,38, -1, -1,41,42,43,44,45, -1,
47, -1, -1,261,262, -1,264,265,266,267,
268,58,59, -1,61, -1,63, -1, -1, -1, -
1, -1, -1, -1, -1,283, -1, -1,261,262, -
1,264,265,266,267,268, -1, -1, -1, -1, -
1,299, -1,301, -1, -1,93,94, -1, -1,
283, -1, -1, -1, -1, -1, -1, -1, -1, -1, -
1, -1, -1, -1, -1, -1,299, -1,301, -1, -
1, -1, -1, -1, -1, -1, -1,124,125, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1,37,
38, -1, -1,41,42,43,44,45, -1,47, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
58,59, -1, -1, -1,63, -1, -1, -1,257, -
1, -1,260,261, -1, -1,264, -1,266,267,
268,269,270,271,272,273,274,275,276,277,
278,279,280,281,282,93,94, -1,286,287,
288,289,290,291,292,293, -1, -1, -1, -1,
38, -1, -1,41, -1,43,44,45, -1, -1, -
1, -1, -1, -1, -1, -1,124,125, -1, -1,
58,59, -1, -1,257,63, -1,260,261, -1, -
1,264, -1, -1,267,268,269,270,271,272,
273,274,275,276,277,278,279,280,281,282,
257, -1, -1,260,261,93,94,264, -1,266,
267,268,269,270,271,272,273,274,275,276,
277,278,279,280,281,282, -1, -1, -1,286,
287,288,289, -1,291,292,124,125, -1,38, -
1, -1,41, -1,43,44,45, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1,58,
59, -1, -1, -1,63, -1, -1, -1, -1, -1, -
1, -1,38, -1, -1,41, -1,43,44,45, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -
1, -1,58,59,93,94, -1,63, -1,257, -
1, -1,260,261, -1, -1,264, -1, -1,267,
268,269,270,271,272,273,274,275,276,277,
278,279,280,281,282,124,125,93,94,287,
288,289, -1,291,292, -1, -1, -1, -1, -1,
38, -1, -1,41, -1, -1,44, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1,124,125,
58,59, -1, -1, -1,63, -1, -1, -1,257, -
1, -1,260,261, -1, -1,264, -1,266,267,
268,269,270,271,272,273,274,275,276,277,
278,279,280,281,282,93,94, -1, -1,287,
288,289, -1,291,292, -1,44, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
58, -1, -1, -1, -1, -1,124,125, -1, -1, -
1,38, -1, -1,41, -1, -1,44, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -
1,58,59, -1, -1, -1,63, -1,257, -1, -
1,260,261, -1, -1,264, -1,266,267,268,
269,270,271,272,273,274,275,276,277,278,
279,280,281,282, -1, -1,93,94,287,288,
289,257,291,292,260,261, -1, -1,264, -1,
266,267,268,269,270,271,272,273,274,275,
276,277,278,279,280,281,282,124,125, -1, -
1,287,288,289, -1,291,292, -1, -1, -1,
38, -1, -1,41, -1, -1,44, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
58,59, -1, -1, -1,63, -1, -1, -1,257, -
1, -1,260,261, -1, -1,264, -1,266,267,
268,269,270,271,272,273,274,275,276,277,
278,279,280,281,282,93,94, -1, -1,287,
288, -1, -1,291,292, -1, -1, -1, -1, -1,
38, -1, -1,41, -1, -1,44, -1, -1, -1, -
1, -1, -1, -1, -1, -1,124,125, -1,257,
58,59,260,261, -1,63,264, -1, -1,267,
268,269,270,271,272,273,274,275,276,277,
278,279,280,281,282, -1, -1, -1, -1, -1,
257, -1, -1,260,261,93,94,264, -1,266,
267,268,269,270,271,272,273,274,275,276,
277,278,279,280,281,282, -1, -1, -1, -1,
287,288, -1, -1,291,292,124,125, -1, -1, -
1, -1,41, -1, -1,44, -1, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1,58,
59, -1, -1, -1,63, -1, -1, -1, -1, -1, -
1, -1, -1, -1, -1,41, -1, -1,44, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -
1, -1,58,59,93,94, -1,63, -1,257, -
1, -1,260,261, -1, -1,264, -1,266,267,
268,269,270,271,272,273,274,275,276,277,
278,279,280,281,282,124,125,93,94, -1, -
1, -1, -1,291,292, -1, -1, -1, -1, -1, -
1, -1, -1,41, -1, -1,44, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1,124,125,
58,59, -1, -1, -1,63, -1, -1, -1,257, -
1, -1,260,261, -1, -1,264, -1,266,267,
268,269,270,271,272,273,274,275,276,277,
278,279,280,281,282,93, -1, -1, -1, -1, -
1, -1,41,291,292,44, -1, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1,58,
59, -1, -1, -1,63, -1,124,125, -1, -1, -
1, -1, -1, -1, -1,41, -1, -1,44, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -
1, -1,58,59,93, -1, -1,63,257, -1, -
1,260,261, -1, -1,264, -1,266,267,268,
269,270,271,272,273,274,275,276,277,278,
279,280,281,282, -1,124,125,93, -1, -1, -
1,257,291,292,260,261, -1, -1,264, -1,
266,267,268,269,270,271,272,273,274,275,
276,277,278,279,280,281,282, -1, -1,125, -
1, -1, -1, -1, -1,291,292, -1, -1, -1, -
1, -1, -1,41, -1, -1,44, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
58,59, -1, -1, -1,63, -1, -1, -1,257, -
1, -1,260,261, -1, -1,264, -1,266,267,
268,269,270,271,272,273,274,275,276,277,
278,279,280,281,282,93, -1, -1, -1, -1, -
1, -1, -1,291,292, -1, -1,41, -1, -1,
44, -1, -1, -1, -1, -1, -1, -1, -1, -1, -
1, -1, -1, -1,58,59, -1,125,257,63, -
1,260,261, -1, -1,264, -1,266,267,268,
269,270,271,272,273,274,275,276,277,278,
279,280,281,282,58, -1, -1, -1, -1,93, -
1,257,291,292,260,261, -1, -1,264, -1,
266,267,268,269,270,271,272,273,274,275,
276,277,278,279,280,281,282,58, -1, -1, -
1,125, -1, -1, -1,291,292, -1, -1, -1, -
1,41, -1, -1,44, -1, -1, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1,58,59, -
1, -1, -1,63, -1, -1, -1, -1, -1, -1, -
1, -1, -1, -1,41, -1, -1,44, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -
1,58,59,93, -1, -1, -1, -1, -1,257, -
1, -1,260,261, -1, -1,264, -1,266,267,
268,269,270,271,272,273,274,275,276,277,
278,279,280,281,282,125,93,58, -1, -1, -
1, -1, -1,291,292, -1, -1, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -
1, -1, -1, -1, -1, -1, -1, -1,125, -1, -
1, -1, -1,257, -1, -1,260,261, -1, -1,
264, -1,266,267,268,269,270,271,272,273,
274,275,276,277,278,279,280,281,282, -1, -
1, -1, -1,257, -1, -1,260,261,292, -1,
264, -1, -1,267,268,269,270,271,272,273,
274,275,276,277,278,279,280,281,282, -1, -
1, -1, -1, -1, -1, -1,257, -1, -1,260,
261, -1, -1,264, -1, -1,267,268,269,270,
271,272,273,274,275,276,277,278,279,280,
281,282, -1, -1, -1, -1, -1,257, -1, -1,
260,261, -1, -1,264, -1,266,267,268,269,
270,271,272,273,274,275,276,277,278,279,
280,281,282, -1, -1, -1, -1, -1, -1, -1,
257, -1,292,260,261, -1, -1,264, -1,266,
267,268,269,270,271,272,273,274,275,276,
277,278,279,280,281,282, -1, -1, -1, -1, -
1, -1, -1, -1, -1, -1,257, -1, -1,260,
261, -1, -1,264, -1, -1,267,268,269,270,
271,272,273,274,275,276,277,278,279,280,
281,282
};
# 1645 "y.tab.c"
int yydebug;
int yynerrs;
int yyerrflag;
int yychar;
short*yyssp;
id*yyvsp;
id yyval;
id yylval;
short yyss[500];
id yyvs[500];

# 1663 "y.tab.c"
int
yyparse()
{
register int yym,yyn,yystate;
# 1679 "y.tab.c"
yynerrs=0;
yyerrflag=0;
yychar=( -1);

yyssp=yyss;
yyvsp=yyvs; *
yyssp=yystate=0;

yyloop:
if(yyn=yydefred[yystate])goto yyreduce;
if(yychar<0)
{
if((yychar=yylex())<0)yychar=0;
# 1702 "y.tab.c"
}
if((yyn=yysindex[yystate])&&(yyn+=yychar)>=0&&
yyn<=4372&&yycheck[yyn]==yychar)
{
# 1711 "y.tab.c"
if(yyssp>=yyss+500-1)
{
goto yyoverflow;
} * ++
yyssp=yystate=yytable[yyn]; * ++
yyvsp=yylval;
yychar=( -1);
if(yyerrflag>0) --yyerrflag;
goto yyloop;
}
if((yyn=yyrindex[yystate])&&(yyn+=yychar)>=0&&
yyn<=4372&&yycheck[yyn]==yychar)
{
yyn=yytable[yyn];
goto yyreduce;
}
if(yyerrflag)goto yyinrecovery;
# 1731 "y.tab.c"
yynewerror:
yyerror("syntax error");
# 1736 "y.tab.c"
yyerrlab: ++
yynerrs;
yyinrecovery:
if(yyerrflag<3)
{
yyerrflag=3;
for(;;)
{
if((yyn=yysindex[ *yyssp])&&(yyn+=256)>=0&&
yyn<=4372&&yycheck[yyn]==256)
{
# 1752 "y.tab.c"
if(yyssp>=yyss+500-1)
{
goto yyoverflow;
} * ++
yyssp=yystate=yytable[yyn]; * ++
yyvsp=yylval;
goto yyloop;
}
else
{
# 1767 "y.tab.c"
if(yyssp<=yyss)goto yyabort; --
yyssp; --
yyvsp;
}
}
}
else
{
if(yychar==0)goto yyabort;
# 1786 "y.tab.c"
yychar=( -1);
goto yyloop;
}
yyreduce:
# 1795 "y.tab.c"
yym=yylen[yyn];
yyval=yyvsp[1-yym];
switch(yyn)
{
case 1:
# 99 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 2:
# 101 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 3:
# 103 "yacc.ym"
{yyval=mkstardecl(yyvsp[ -1],yyvsp[0]);}
break;
case 4:
# 105 "yacc.ym"
{yyval=mkprefixdecl(yyvsp[ -1],yyvsp[0]);}
break;
case 5:
# 107 "yacc.ym"
{yyval=mkstardecl(yyvsp[ -2],mkprefixdecl(yyvsp[ -1],yyvsp[0]));}
break;
case 6:
# 111 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 7:
# 113 "yacc.ym"
{yyval=mkprecdecl(yyvsp[ -1],yyvsp[0]);}
break;
case 8:
# 117 "yacc.ym"
{yyval=mkprecdecl((id)0,yyvsp[ -1]);}
break;
case 9:
# 119 "yacc.ym"
{yyval=mkarraydecl((id)0,yyvsp[ -1]);}
break;
case 10:
# 121 "yacc.ym"
{yyval=mkarraydecl(yyvsp[ -3],yyvsp[ -1]);}
break;
case 11:
# 123 "yacc.ym"
{yyval=mkfundecl(yyvsp[ -3],yyvsp[ -1]);}
break;
case 12:
# 125 "yacc.ym"
{yyval=mkpostfixdecl(yyvsp[ -1],yyvsp[0]);}
break;
case 13:
# 127 "yacc.ym"
{yyval=mkpostfixdecl(yyvsp[ -1],yyvsp[0]);}
break;
case 14:
# 131 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 15:
# 133 "yacc.ym"
{yyval=mkbinexpr(yyvsp[ -2],"&",yyvsp[0]);}
break;
case 19:
# 137 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 20:
# 141 "yacc.ym"
{yyval=mkbuiltincall(yyvsp[ -3],mklist((id)0,mkconstexpr((id)0,yyvsp[ -1])));}
break;
case 21:
# 145 "yacc.ym"
{yyval=(id)0;}
break;
case 22:
# 147 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 23:
# 149 "yacc.ym"
{yyval=mklist(yyvsp[ -2],yyvsp[0]);}
break;
case 24:
# 153 "yacc.ym"
{yyval=mkasmop(yyvsp[ -3],yyvsp[ -1]);}
break;
case 25:
# 157 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 26:
# 159 "yacc.ym"
{yyval=mklist(yyvsp[ -2],yyvsp[0]);}
break;
case 27:
# 163 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 28:
# 165 "yacc.ym"
{
id objcT0;

# 165 "yacc.ym"
yyval=mkassignexpr(yyvsp[ -2],(objcT0=yyvsp[ -1],(*(STR(*)(id,SEL))_imp(objcT0,selTransTbl[0]))(objcT0,selTransTbl[0])),yyvsp[0]);}
break;
case 29:
# 167 "yacc.ym"
{okblock=1;}
break;
case 30:
# 169 "yacc.ym"
{okblock=0;yyval=mkassignexpr(yyvsp[ -3],"=",yyvsp[0]);}
break;
case 31:
# 173 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 32:
# 175 "yacc.ym"
{yyval=(id)0;}
break;
case 33:
# 179 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 34:
# 181 "yacc.ym"
{yyval=mklist(yyvsp[ -2],yyvsp[0]);}
break;
case 35:
# 185 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -1],(id)0,(id)0,(id)0,(id)0,yyvsp[0]);}
break;
case 36:
# 187 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -4],yyvsp[ -3],(id)0,(id)0,yyvsp[ -1],yyvsp[0]);}
break;
case 37:
# 189 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -4],yyvsp[ -3],(id)0,yyvsp[ -1],(id)0,yyvsp[0]);}
break;
case 38:
# 191 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -5],yyvsp[ -4],(id)0,yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 39:
# 193 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -4],yyvsp[ -3],yyvsp[ -1],(id)0,(id)0,yyvsp[0]);}
break;
case 40:
# 195 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -5],yyvsp[ -4],yyvsp[ -2],yyvsp[ -1],(id)0,yyvsp[0]);}
break;
case 41:
# 197 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -6],yyvsp[ -5],yyvsp[ -3],yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 42:
# 199 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -2],(id)0,(id)0,(id)0,yyvsp[ -1],yyvsp[0]);}
break;
case 43:
# 201 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -2],(id)0,(id)0,yyvsp[ -1],(id)0,yyvsp[0]);}
break;
case 44:
# 203 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -3],(id)0,(id)0,yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 45:
# 205 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -2],(id)0,yyvsp[ -1],(id)0,(id)0,yyvsp[0]);}
break;
case 46:
# 207 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -3],(id)0,yyvsp[ -2],yyvsp[ -1],(id)0,yyvsp[0]);}
break;
case 47:
# 209 "yacc.ym"
{yyval=mkblockexpr(yyvsp[ -4],(id)0,yyvsp[ -3],yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 48:
# 213 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 49:
# 215 "yacc.ym"
{yyval=mklist(yyvsp[ -2],yyvsp[0]);}
break;
case 50:
# 219 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 51:
# 221 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 52:
# 225 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 53:
# 227 "yacc.ym"
{yyval=mklist(yyvsp[ -2],yyvsp[0]);}
break;
case 54:
# 231 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 55:
# 233 "yacc.ym"
{yyval=mkbinexpr(yyvsp[ -2],"^",yyvsp[0]);}
break;
case 56:
# 237 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 57:
# 239 "yacc.ym"
{yyval=mkcastexpr(yyvsp[ -2],yyvsp[0]);}
break;
case 58:
# 241 "yacc.ym"
{yyval=mkcastexpr(yyvsp[ -4],mklistexpr(yyvsp[ -2],yyvsp[ -1],yyvsp[0]));}
break;
case 59:
# 243 "yacc.ym"
{yyval=mkcastexpr(yyvsp[ -5],mklistexpr(yyvsp[ -3],yyvsp[ -2],yyvsp[0]));}
break;
case 60:
# 247 "yacc.ym"
{yyval=mkclassdef(yyvsp[ -2],yyvsp[ -1],(id)0,yyvsp[0],(id)0);}
break;
case 61:
# 249 "yacc.ym"
{yyval=mkclassdef(yyvsp[ -4],yyvsp[ -3],(id)0,yyvsp[ -2],yyvsp[0]);}
break;
case 62:
# 251 "yacc.ym"
{yyval=mkclassdef(yyvsp[ -1],yyvsp[0],(id)0,(id)0,(id)0);}
break;
case 63:
# 253 "yacc.ym"
{yyval=mkclassdef(yyvsp[ -3],yyvsp[ -2],yyvsp[0],(id)0,(id)0);}
break;
case 64:
# 255 "yacc.ym"
{yyval=mkclassdef(yyvsp[ -4],yyvsp[ -3],yyvsp[ -1],yyvsp[0],(id)0);}
break;
case 65:
# 257 "yacc.ym"
{yyval=mkclassdef(yyvsp[ -6],yyvsp[ -5],yyvsp[ -3],yyvsp[ -2],yyvsp[0]);}
break;
case 66:
# 261 "yacc.ym"
{yyval=mkcompstmt(yyvsp[ -1],(id)0,(id)0,yyvsp[0]);}
break;
case 67:
# 263 "yacc.ym"
{yyval=mkcompstmt(yyvsp[ -2],(id)0,yyvsp[ -1],yyvsp[0]);}
break;
case 68:
# 265 "yacc.ym"
{yyval=mkcompstmt(yyvsp[ -2],yyvsp[ -1],(id)0,yyvsp[0]);}
break;
case 69:
# 267 "yacc.ym"
{yyval=mkcompstmt(yyvsp[ -3],yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 70:
# 271 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 71:
# 273 "yacc.ym"
{yyval=mkcondexpr(yyvsp[ -4],yyvsp[ -2],yyvsp[0]);}
break;
case 72:
# 275 "yacc.ym"
{yyval=mkcondexpr(yyvsp[ -3],(id)0,yyvsp[0]);}
break;
case 73:
# 279 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 74:
# 283 "yacc.ym"
{yyval=mkdatadef((id)0,yyvsp[ -1],(id)0,(id)0);}
break;
case 75:
# 285 "yacc.ym"
{yyval=yyvsp[ -1];}
break;
case 76:
# 287 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 77:
# 289 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 78:
# 293 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 79:
# 295 "yacc.ym"
{yyval=mklist(yyvsp[ -1],yyvsp[0]);}
break;
case 80:
# 299 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 81:
# 301 "yacc.ym"
{yyval=mklist(yyvsp[ -1],yyvsp[0]);}
break;
case 82:
# 303 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 83:
# 305 "yacc.ym"
{yyval=mklist(yyvsp[ -1],yyvsp[0]);}
break;
case 84:
# 307 "yacc.ym"
{yyval=mklist(yyvsp[ -2],yyvsp[ -1]);yyval=mklist(yyvsp[ -2],yyvsp[0]);}
break;
case 85:
# 309 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 86:
# 313 "yacc.ym"
{datadefokblock((id)0,yyvsp[ -1],yyvsp[0]);}
break;
case 87:
# 315 "yacc.ym"
{okblock=0;yyval=mkdatadef((id)0,yyvsp[ -3],yyvsp[ -2],yyvsp[0]);}
break;
case 88:
# 317 "yacc.ym"
{datadefokblock(yyvsp[ -2],(id)0,yyvsp[0]);}
break;
case 89:
# 319 "yacc.ym"
{okblock=0;yyval=mkdatadef(yyvsp[ -4],(id)0,yyvsp[ -2],yyvsp[0]);}
break;
case 90:
# 323 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 91:
# 325 "yacc.ym"
{yyval=mkstardecl(yyvsp[ -1],yyvsp[0]);}
break;
case 92:
# 327 "yacc.ym"
{yyval=mkprefixdecl(yyvsp[ -1],yyvsp[0]);}
break;
case 93:
# 329 "yacc.ym"
{yyval=mkstardecl(yyvsp[ -2],mkprefixdecl(yyvsp[ -1],yyvsp[0]));}
break;
case 94:
# 333 "yacc.ym"
{yyval=mkdecl(yyvsp[0]);}
break;
case 95:
# 335 "yacc.ym"
{yyval=mkprecdecl((id)0,yyvsp[ -1]);}
break;
case 96:
# 337 "yacc.ym"
{yyval=mkprecdecl(yyvsp[ -2],yyvsp[ -1]);}
break;
case 97:
# 339 "yacc.ym"
{yyval=mkarraydecl(yyvsp[ -3],yyvsp[ -1]);}
break;
case 98:
# 341 "yacc.ym"
{yyval=mkfundecl(yyvsp[ -3],yyvsp[ -1]);}
break;
case 99:
# 343 "yacc.ym"
{yyval=mkpostfixdecl(yyvsp[ -1],yyvsp[0]);}
break;
case 100:
# 345 "yacc.ym"
{yyval=mkpostfixdecl(yyvsp[ -1],yyvsp[0]);}
break;
case 101:
# 349 "yacc.ym"
{yyval=mkencodeexpr(yyvsp[ -1]);}
break;
case 102:
# 353 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 103:
# 355 "yacc.ym"
{
id objcT1;

# 355 "yacc.ym"
yyval=mkrelexpr(yyvsp[ -2],(objcT1=yyvsp[ -1],(*(STR(*)(id,SEL))_imp(objcT1,selTransTbl[0]))(objcT1,selTransTbl[0])),yyvsp[0]);}
break;
case 104:
# 359 "yacc.ym"
{yyval=mkenumspec(yyvsp[ -4],yyvsp[ -3],yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 105:
# 361 "yacc.ym"
{yyval=mkenumspec(yyvsp[ -5],yyvsp[ -4],yyvsp[ -3],yyvsp[ -2],yyvsp[0]);}
break;
case 106:
# 363 "yacc.ym"
{yyval=mkenumspec(yyvsp[ -3],(id)0,yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 107:
# 365 "yacc.ym"
{yyval=mkenumspec(yyvsp[ -4],(id)0,yyvsp[ -3],yyvsp[ -2],yyvsp[0]);}
break;
case 108:
# 367 "yacc.ym"
{yyval=mkenumspec(yyvsp[ -1],yyvsp[0],(id)0,(id)0,(id)0);}
break;
case 109:
# 371 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 110:
# 373 "yacc.ym"
{yyval=mklist(yyvsp[ -1],yyvsp[0]);}
break;
case 111:
# 375 "yacc.ym"
{yyval=mklist(yyvsp[ -2],yyvsp[0]);}
break;
case 112:
# 379 "yacc.ym"
{yyval=mkenumerator(yyvsp[0],(id)0);}
break;
case 113:
# 381 "yacc.ym"
{yyval=mkenumerator(yyvsp[ -2],yyvsp[0]);}
break;
case 114:
# 383 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 115:
# 387 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 116:
# 389 "yacc.ym"
{yyval=mkcommaexpr(yyvsp[ -2],yyvsp[0]);}
break;
case 117:
# 393 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 118:
# 395 "yacc.ym"
{yyval=mklist(yyvsp[ -2],yyvsp[0]);}
break;
case 119:
# 399 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 120:
# 401 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 121:
# 403 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 122:
# 405 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 123:
# 407 "yacc.ym"
{yyval=(id)0;finclassdef();}
break;
case 124:
# 409 "yacc.ym"
{gc(';');yyval=(id)0;}
break;
case 125:
# 411 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 126:
# 413 "yacc.ym"
{yyval=(id)0;}
break;
case 127:
# 417 "yacc.ym"
{
id objcT2,objcT3,objcT4;

# 417 "yacc.ym"
(objcT2=yyvsp[ -2],(*_imp(objcT2,selTransTbl[1]))(objcT2,selTransTbl[1]));(objcT3=yyvsp[ -1],(*_imp(objcT3,selTransTbl[1]))(objcT3,selTransTbl[1]));(objcT4=yyvsp[0],(*_imp(objcT4,selTransTbl[1]))(objcT4,selTransTbl[1]));}
break;
case 128:
# 419 "yacc.ym"
{
id objcT5,objcT6;

# 419 "yacc.ym"
(objcT5=yyvsp[ -1],(*_imp(objcT5,selTransTbl[1]))(objcT5,selTransTbl[1]));(objcT6=yyvsp[0],(*_imp(objcT6,selTransTbl[1]))(objcT6,selTransTbl[1]));}
break;
case 129:
# 421 "yacc.ym"
{
id objcT7;

# 421 "yacc.ym"
(objcT7=yyvsp[0],(*_imp(objcT7,selTransTbl[1]))(objcT7,selTransTbl[1]));}
break;
case 130:
# 426 "yacc.ym"
{yyval=mkfunbody((id)0,yyvsp[0]);}
break;
case 131:
# 428 "yacc.ym"
{yyval=mkfunbody(yyvsp[ -1],yyvsp[0]);}
break;
case 132:
# 432 "yacc.ym"
{declarefun((id)0,yyvsp[0]);}
break;
case 133:
# 434 "yacc.ym"
{yyval=mkfundef((id)0,yyvsp[ -2],yyvsp[0]);}
break;
case 134:
# 436 "yacc.ym"
{declarefun(yyvsp[ -1],yyvsp[0]);}
break;
case 135:
# 438 "yacc.ym"
{yyval=mkfundef(yyvsp[ -3],yyvsp[ -2],yyvsp[0]);}
break;
case 136:
# 444 "yacc.ym"
{yyval=mkasmstmt(yyvsp[ -5],yyvsp[ -4],yyvsp[ -2],(id)0,(id)0,(id)0);}
break;
case 137:
# 446 "yacc.ym"
{yyval=mkasmstmt(yyvsp[ -7],yyvsp[ -6],yyvsp[ -4],yyvsp[ -2],(id)0,(id)0);}
break;
case 138:
# 448 "yacc.ym"
{yyval=mkasmstmt(yyvsp[ -9],yyvsp[ -8],yyvsp[ -6],yyvsp[ -4],yyvsp[ -2],(id)0);}
break;
case 139:
# 450 "yacc.ym"
{yyval=mkasmstmt(yyvsp[ -11],yyvsp[ -10],yyvsp[ -8],yyvsp[ -6],yyvsp[ -4],yyvsp[ -2]);}
break;
case 140:
# 454 "yacc.ym"
{yyval=mkgnuattribdecl(yyvsp[ -5],yyvsp[ -2]);}
break;
case 141:
# 457 "yacc.ym"
{yyval=mkgnuattrib((id)0,(id)0);}
break;
case 142:
# 459 "yacc.ym"
{yyval=mkgnuattrib(yyvsp[0],(id)0);}
break;
case 143:
# 461 "yacc.ym"
{yyval=mkgnuattrib(yyvsp[ -3],yyvsp[ -1]);}
break;
case 144:
# 465 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 145:
# 467 "yacc.ym"
{yyval=mklabeledstmt(yyvsp[ -2],yyvsp[0]);}
break;
case 146:
# 469 "yacc.ym"
{yyval=mklabeledstmt(yyvsp[ -1],yyvsp[0]);}
break;
case 147:
# 471 "yacc.ym"
{yyval=mklistexpr(yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 148:
# 473 "yacc.ym"
{yyval=mklistexpr(yyvsp[ -3],yyvsp[ -2],yyvsp[0]);}
break;
case 149:
# 477 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 150:
# 479 "yacc.ym"
{yyval=mklist(yyvsp[ -2],yyvsp[0]);}
break;
case 151:
# 483 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 152:
# 485 "yacc.ym"
{yyval=mklist(yyvsp[ -2],yyvsp[0]);}
break;
case 153:
# 489 "yacc.ym"
{yyval=(id)0;}
break;
case 154:
# 491 "yacc.ym"
{yyval=yyvsp[ -1];}
break;
case 155:
# 495 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 156:
# 497 "yacc.ym"
{yyval=mklist(yyvsp[ -1],yyvsp[0]);}
break;
case 157:
# 500 "yacc.ym"
{okblock=1;}
break;
case 158:
# 501 "yacc.ym"
{okblock=0;yyval=mkkeywarg(yyvsp[ -3],yyvsp[0]);}
break;
case 159:
# 502 "yacc.ym"
{okblock=1;}
break;
case 160:
# 503 "yacc.ym"
{okblock=0;yyval=mkkeywarg((id)0,yyvsp[0]);}
break;
case 161:
# 507 "yacc.ym"
{yyval=mkkeywdecl(yyvsp[ -2],(id)0,yyvsp[0]);}
break;
case 162:
# 509 "yacc.ym"
{yyval=mkkeywdecl(yyvsp[ -5],yyvsp[ -2],yyvsp[0]);}
break;
case 163:
# 511 "yacc.ym"
{yyval=mkkeywdecl((id)0,(id)0,yyvsp[0]);}
break;
case 164:
# 513 "yacc.ym"
{yyval=mkkeywdecl((id)0,yyvsp[ -2],yyvsp[0]);}
break;
case 165:
# 517 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 166:
# 519 "yacc.ym"
{yyval=mklist(yyvsp[ -1],yyvsp[0]);}
break;
case 167:
# 523 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 168:
# 525 "yacc.ym"
{yyval=mkbinexpr(yyvsp[ -2],"&&",yyvsp[0]);}
break;
case 169:
# 529 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 170:
# 531 "yacc.ym"
{yyval=mkbinexpr(yyvsp[ -2],"||",yyvsp[0]);}
break;
case 171:
# 535 "yacc.ym"
{yyval=(id)0;declaremeth((BOOL)1,yyvsp[ -1]);}
break;
case 172:
# 537 "yacc.ym"
{yyval=(id)0;declaremeth((BOOL)0,yyvsp[ -1]);}
break;
case 173:
# 539 "yacc.ym"
{declaremeth((BOOL)1,yyvsp[0]);}
break;
case 174:
# 541 "yacc.ym"
{yyval=mkmethdef((BOOL)1,yyvsp[ -2],yyvsp[0]);}
break;
case 175:
# 543 "yacc.ym"
{declaremeth((BOOL)0,yyvsp[0]);}
break;
case 176:
# 545 "yacc.ym"
{yyval=mkmethdef((BOOL)0,yyvsp[ -2],yyvsp[0]);}
break;
case 177:
# 549 "yacc.ym"
{yyval=mkmethproto(yyvsp[ -2],yyvsp[0],(id)0,(BOOL)0);}
break;
case 178:
# 551 "yacc.ym"
{yyval=mkmethproto(yyvsp[ -2],(id)0,yyvsp[0],(BOOL)0);}
break;
case 179:
# 553 "yacc.ym"
{yyval=mkmethproto(yyvsp[ -4],(id)0,yyvsp[ -2],(BOOL)1);}
break;
case 180:
# 555 "yacc.ym"
{yyval=mkmethproto((id)0,yyvsp[0],(id)0,(BOOL)0);}
break;
case 181:
# 557 "yacc.ym"
{yyval=mkmethproto((id)0,(id)0,yyvsp[0],(BOOL)0);}
break;
case 182:
# 559 "yacc.ym"
{yyval=mkmethproto((id)0,(id)0,yyvsp[ -2],(BOOL)1);}
break;
case 183:
# 563 "yacc.ym"
{yyval=mkmethproto((id)0,yyvsp[0],(id)0,(BOOL)0);}
break;
case 184:
# 565 "yacc.ym"
{yyval=mkmethproto((id)0,(id)0,yyvsp[0],(BOOL)0);}
break;
case 185:
# 568 "yacc.ym"
{okblock=1;}
break;
case 186:
# 568 "yacc.ym"
{okblock=0;}
break;
case 187:
# 569 "yacc.ym"
{yyval=mkmesgexpr(yyvsp[ -3],yyvsp[ -1]);}
break;
case 188:
# 573 "yacc.ym"
{yyval=(id)0;}
break;
case 189:
# 575 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 190:
# 579 "yacc.ym"
{yyval=(id)0;}
break;
case 191:
# 581 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 192:
# 585 "yacc.ym"
{yyval=(id)0;}
break;
case 193:
# 587 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 194:
# 591 "yacc.ym"
{yyval=(id)0;}
break;
case 195:
# 593 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 196:
# 597 "yacc.ym"
{yyval=(id)0;}
break;
case 197:
# 599 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 198:
# 603 "yacc.ym"
{yyval=(id)0;}
break;
case 199:
# 605 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 200:
# 609 "yacc.ym"
{yyval=(id)0;}
break;
case 201:
# 611 "yacc.ym"
{yyval=mkparmdeflist((id)0,(id)0,(BOOL)1);}
break;
case 202:
# 613 "yacc.ym"
{yyval=mkparmdeflist(yyvsp[0],(id)0,(BOOL)0);}
break;
case 203:
# 615 "yacc.ym"
{yyval=mkparmdeflist((id)0,yyvsp[0],(BOOL)0);}
break;
case 204:
# 617 "yacc.ym"
{yyval=mkparmdeflist((id)0,yyvsp[ -2],(BOOL)1);}
break;
case 205:
# 621 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 206:
# 623 "yacc.ym"
{yyval=mkbinexpr(yyvsp[ -2],"|",yyvsp[0]);}
break;
case 207:
# 627 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 208:
# 629 "yacc.ym"
{yyval=mkbinexpr(yyvsp[ -2],"+",yyvsp[0]);}
break;
case 209:
# 631 "yacc.ym"
{yyval=mkbinexpr(yyvsp[ -2],"-",yyvsp[0]);}
break;
case 210:
# 635 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 211:
# 639 "yacc.ym"
{yyval=(id)0;}
break;
case 212:
# 641 "yacc.ym"
{yyval=(id)0;}
break;
case 213:
# 645 "yacc.ym"
{yyval=mkidentexpr(yyvsp[0]);}
break;
case 214:
# 647 "yacc.ym"
{yyval=mkconstexpr(yyvsp[0],(id)0);}
break;
case 215:
# 649 "yacc.ym"
{yyval=mkconstexpr((id)0,yyvsp[0]);}
break;
case 216:
# 651 "yacc.ym"
{yyval=mkconstexpr(yyvsp[0],(id)0);}
break;
case 217:
# 653 "yacc.ym"
{yyval=mkprecexpr(yyvsp[ -1]);}
break;
case 218:
# 655 "yacc.ym"
{yyval=mkbracedgroup(yyvsp[ -1]);}
break;
case 219:
# 657 "yacc.ym"
{yyval=mkindexexpr(yyvsp[ -3],yyvsp[ -1]);}
break;
case 220:
# 659 "yacc.ym"
{yyval=mkfuncall(yyvsp[ -3],yyvsp[ -1]);}
break;
case 221:
# 661 "yacc.ym"
{yyval=mkpostfixexpr(yyvsp[ -3],mkprecexpr(yyvsp[ -1]));}
break;
case 222:
# 663 "yacc.ym"
{yyval=mkdotexpr(yyvsp[ -2],yyvsp[0]);}
break;
case 223:
# 665 "yacc.ym"
{yyval=mkdotexpr(yyvsp[ -2],yyvsp[0]);}
break;
case 224:
# 667 "yacc.ym"
{yyval=mkarrowexpr(yyvsp[ -2],yyvsp[0]);}
break;
case 225:
# 669 "yacc.ym"
{yyval=mkarrowexpr(yyvsp[ -2],yyvsp[0]);}
break;
case 226:
# 671 "yacc.ym"
{yyval=mkpostfixexpr(yyvsp[ -1],yyvsp[0]);}
break;
case 227:
# 673 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 228:
# 675 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 229:
# 677 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 230:
# 679 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 231:
# 683 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 232:
# 685 "yacc.ym"
{yyval=mklist(yyvsp[ -2],yyvsp[0]);}
break;
case 233:
# 689 "yacc.ym"
{yyval=mkparmdef((id)0,yyvsp[0],(id)0);}
break;
case 234:
# 691 "yacc.ym"
{yyval=mkparmdef(yyvsp[ -1],yyvsp[0],(id)0);}
break;
case 235:
# 693 "yacc.ym"
{yyval=mkparmdef((id)0,yyvsp[ -1],yyvsp[0]);}
break;
case 236:
# 695 "yacc.ym"
{yyval=mkparmdef(yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 237:
# 697 "yacc.ym"
{yyval=mkparmdef((id)0,yyvsp[ -1],yyvsp[0]);}
break;
case 238:
# 699 "yacc.ym"
{yyval=mkparmdef(yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 239:
# 703 "yacc.ym"
{yyval=mkpointer((id)0,(id)0);}
break;
case 240:
# 705 "yacc.ym"
{yyval=mkpointer(yyvsp[0],(id)0);}
break;
case 241:
# 707 "yacc.ym"
{yyval=mkpointer((id)0,yyvsp[0]);}
break;
case 242:
# 709 "yacc.ym"
{yyval=mkpointer(yyvsp[ -1],yyvsp[0]);}
break;
case 243:
# 713 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 244:
# 715 "yacc.ym"
{
id objcT8;

# 715 "yacc.ym"
yyval=mkrelexpr(yyvsp[ -2],(objcT8=yyvsp[ -1],(*(STR(*)(id,SEL))_imp(objcT8,selTransTbl[0]))(objcT8,selTransTbl[0])),yyvsp[0]);}
break;
case 245:
# 719 "yacc.ym"
{warn("ignoring @requires");}
break;
case 262:
# 726 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 263:
# 730 "yacc.ym"
{yyval=mkselarg((id)0,yyvsp[0],0);}
break;
case 264:
# 732 "yacc.ym"
{yyval=mkselarg(yyvsp[ -1],(id)0,1);}
break;
case 265:
# 734 "yacc.ym"
{yyval=mkselarg(yyvsp[ -2],yyvsp[ -1],1);}
break;
case 266:
# 738 "yacc.ym"
{yyval=mkselectorexpr(yyvsp[ -1]);}
break;
case 267:
# 742 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 268:
# 744 "yacc.ym"
{
id objcT9;

# 744 "yacc.ym"
yyval=mkbinexpr(yyvsp[ -2],(objcT9=yyvsp[ -1],(*(STR(*)(id,SEL))_imp(objcT9,selTransTbl[0]))(objcT9,selTransTbl[0])),yyvsp[0]);}
break;
case 269:
# 748 "yacc.ym"
{yyval=mkstructspec(yyvsp[ -4],yyvsp[ -3],yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 270:
# 750 "yacc.ym"
{yyval=mkstructspec(yyvsp[ -4],yyvsp[ -3],yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 271:
# 752 "yacc.ym"
{yyval=mkstructspec(yyvsp[ -3],(id)0,yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 272:
# 754 "yacc.ym"
{yyval=mkstructspec(yyvsp[ -1],yyvsp[0],(id)0,(id)0,(id)0);}
break;
case 273:
# 756 "yacc.ym"
{yyval=mkstructspec(yyvsp[ -1],yyvsp[0],(id)0,(id)0,(id)0);}
break;
case 274:
# 758 "yacc.ym"
{yyval=mkpostfixdecl(yyvsp[ -1],yyvsp[0]);}
break;
case 275:
# 762 "yacc.ym"
{yyval=mklist((id)0,(id)0);}
break;
case 276:
# 764 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 277:
# 768 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 278:
# 770 "yacc.ym"
{yyval=mklist(yyvsp[ -1],yyvsp[0]);}
break;
case 279:
# 772 "yacc.ym"
{yyval=atdefsaddall((id)0,yyvsp[ -1]);}
break;
case 280:
# 774 "yacc.ym"
{yyval=atdefsaddall(yyvsp[ -4],yyvsp[ -1]);}
break;
case 281:
# 778 "yacc.ym"
{yyval=yyvsp[ -1];}
break;
case 282:
# 780 "yacc.ym"
{yyval=mkcomponentdef((id)0,yyvsp[ -1],(id)0);}
break;
case 283:
# 782 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 284:
# 786 "yacc.ym"
{yyval=mkcomponentdef((id)0,yyvsp[ -1],yyvsp[0]);}
break;
case 285:
# 788 "yacc.ym"
{yyval=mkcomponentdef(yyvsp[ -2],(id)0,yyvsp[0]);}
break;
case 286:
# 792 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 287:
# 794 "yacc.ym"
{yyval=mkbitfielddecl((id)0,yyvsp[0]);}
break;
case 288:
# 796 "yacc.ym"
{yyval=mkbitfielddecl(yyvsp[ -2],yyvsp[0]);}
break;
case 289:
# 800 "yacc.ym"
{
# 806 "yacc.ym"
yyval=yyvsp[0];
# 810 "yacc.ym"
}
break;
case 290:
# 814 "yacc.ym"
{yyval=mkexprstmt(yyvsp[ -1]);}
break;
case 291:
# 816 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 292:
# 818 "yacc.ym"
{yyval=mklabeledstmt(yyvsp[ -2],yyvsp[0]);}
break;
case 293:
# 820 "yacc.ym"
{yyval=mkcasestmt(yyvsp[ -3],yyvsp[ -2],yyvsp[0]);}
break;
case 294:
# 822 "yacc.ym"
{yyval=mkdefaultstmt(yyvsp[ -2],yyvsp[0]);}
break;
case 295:
# 824 "yacc.ym"
{yyval=mkifstmt(yyvsp[ -4],yyvsp[ -2],yyvsp[0]);}
break;
case 296:
# 826 "yacc.ym"
{yyval=mkifelsestmt(yyvsp[ -6],yyvsp[ -4],yyvsp[ -2],yyvsp[ -1],yyvsp[0]);}
break;
case 297:
# 828 "yacc.ym"
{yyval=mkswitchstmt(yyvsp[ -4],yyvsp[ -2],yyvsp[0]);}
break;
case 298:
# 830 "yacc.ym"
{yyval=mkwhilestmt(yyvsp[ -4],yyvsp[ -2],yyvsp[0]);}
break;
case 299:
# 832 "yacc.ym"
{yyval=mkdostmt(yyvsp[ -6],yyvsp[ -5],yyvsp[ -4],yyvsp[ -2]);}
break;
case 300:
# 834 "yacc.ym"
{yyval=mkforstmt(yyvsp[ -8],yyvsp[ -6],yyvsp[ -4],yyvsp[ -2],yyvsp[0]);}
break;
case 301:
# 836 "yacc.ym"
{yyval=mkgotostmt(yyvsp[ -2],yyvsp[ -1]);}
break;
case 302:
# 838 "yacc.ym"
{yyval=mkcontinuestmt(yyvsp[ -1]);}
break;
case 303:
# 840 "yacc.ym"
{yyval=mkbreakstmt(yyvsp[ -1]);}
break;
case 304:
# 842 "yacc.ym"
{yyval=mkreturnstmt(yyvsp[ -1],(id)0);}
break;
case 305:
# 844 "yacc.ym"
{yyval=mkreturnstmt(yyvsp[ -2],yyvsp[ -1]);}
break;
case 306:
# 846 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 307:
# 848 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 308:
# 850 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 309:
# 854 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 310:
# 856 "yacc.ym"
{yyval=mklist(yyvsp[ -1],yyvsp[0]);}
break;
case 311:
# 860 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 312:
# 862 "yacc.ym"
{yyval=mklist(yyvsp[ -1],yyvsp[0]);}
break;
case 313:
# 866 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 314:
# 868 "yacc.ym"
{yyval=mkbinexpr(yyvsp[ -2],"*",yyvsp[0]);}
break;
case 315:
# 870 "yacc.ym"
{yyval=mkbinexpr(yyvsp[ -2],"/",yyvsp[0]);}
break;
case 316:
# 872 "yacc.ym"
{yyval=mkbinexpr(yyvsp[ -2],"%",yyvsp[0]);}
break;
case 317:
# 876 "yacc.ym"
{procextdef(yyvsp[0]);}
break;
case 318:
# 878 "yacc.ym"
{procextdef(yyvsp[0]);}
break;
case 319:
# 882 "yacc.ym"
{yyval=mktypename(yyvsp[0],(id)0);}
break;
case 320:
# 884 "yacc.ym"
{yyval=mktypename(yyvsp[ -1],yyvsp[0]);}
break;
case 321:
# 888 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 322:
# 890 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 323:
# 892 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 324:
# 894 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 325:
# 896 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 326:
# 898 "yacc.ym"
{yyval=mktypeof(yyvsp[ -3],yyvsp[ -1]);}
break;
case 327:
# 902 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 328:
# 904 "yacc.ym"
{yyval=mklist(yyvsp[ -1],yyvsp[0]);}
break;
case 329:
# 908 "yacc.ym"
{yyval=mklist((id)0,yyvsp[0]);}
break;
case 330:
# 910 "yacc.ym"
{yyval=mklist(yyvsp[ -1],yyvsp[0]);}
break;
case 331:
# 914 "yacc.ym"
{yyval=yyvsp[0];}
break;
case 332:
# 916 "yacc.ym"
{
id objcT10;

# 916 "yacc.ym"
yyval=mkunaryexpr((objcT10=yyvsp[ -1],(*(STR(*)(id,SEL))_imp(objcT10,selTransTbl[0]))(objcT10,selTransTbl[0])),yyvsp[0]);}
break;
case 333:
# 918 "yacc.ym"
{
id objcT11;

# 918 "yacc.ym"
yyval=mkunaryexpr((objcT11=yyvsp[ -1],(*(STR(*)(id,SEL))_imp(objcT11,selTransTbl[0]))(objcT11,selTransTbl[0])),yyvsp[0]);}
break;
case 334:
# 920 "yacc.ym"
{yyval=mkunaryexpr("!",yyvsp[0]);}
break;
case 335:
# 922 "yacc.ym"
{yyval=mkunaryexpr("~",yyvsp[0]);}
break;
case 336:
# 924 "yacc.ym"
{yyval=mkaddressof(yyvsp[0]);}
break;
case 337:
# 926 "yacc.ym"
{yyval=mkdereference(yyvsp[0]);}
break;
case 338:
# 928 "yacc.ym"
{yyval=mkunaryexpr("+",yyvsp[0]);}
break;
case 339:
# 930 "yacc.ym"
{yyval=mkunaryexpr("-",yyvsp[0]);}
break;
case 340:
# 932 "yacc.ym"
{yyval=mksizeof(yyvsp[0]);}
break;
case 341:
# 934 "yacc.ym"
{yyval=mkbuiltincall(yyvsp[ -3],mklist((id)0,yyvsp[ -1]));}
break;
case 342:
# 936 "yacc.ym"
{yyval=mkbuiltincall(yyvsp[ -3],yyvsp[ -1]);}
break;
case 343:
# 938 "yacc.ym"
{
id objcT12;

# 938 "yacc.ym"
yyval=mkunaryexpr((objcT12=yyvsp[ -1],(*(STR(*)(id,SEL))_imp(objcT12,selTransTbl[0]))(objcT12,selTransTbl[0])),yyvsp[0]);}
break;
# 3106 "y.tab.c"
}
yyssp-=yym;
yystate= *yyssp;
yyvsp-=yym;
yym=yylhs[yyn];
if(yystate==0&&yym==0)
{
# 3118 "y.tab.c"
yystate=22; * ++
yyssp=22; * ++
yyvsp=yyval;
if(yychar<0)
{
if((yychar=yylex())<0)yychar=0;
# 3134 "y.tab.c"
}
if(yychar==0)goto yyaccept;
goto yyloop;
}
if((yyn=yygindex[yym])&&(yyn+=yystate)>=0&&
yyn<=4372&&yycheck[yyn]==yystate)
yystate=yytable[yyn];
else
yystate=yydgoto[yym];
# 3148 "y.tab.c"
if(yyssp>=yyss+500-1)
{
goto yyoverflow;
} * ++
yyssp=yystate; * ++
yyvsp=yyval;
goto yyloop;
yyoverflow:
yyerror("yacc stack overflow");
yyabort:
return(1);
yyaccept:
return(0);
}
static char *_selTransTbl[] ={
"strCopy",
"gen",
0
};
struct modDescriptor yacc_modDesc = {
  "yacc",
  "objc3.1.32",
  0L,
  0,
  0,
  0,
  2,
  _selTransTbl,
  0
};
struct modDescriptor *_OBJCBIND_yacc(void)
{
  selTransTbl = _selTransTbl;
  return &yacc_modDesc;
}
int _OBJCPOSTLINK_yacc = 1;


